# coding: utf8
"""Fix join words"""

from typing import Dict

WORDS_SPACE: Dict[str, str] = {"کردیا": "کر دیا",
                               "کردی": "کر دی",
                               "ہوگیا": "ہو گیا",
                               "جاسکتے": "جا سکتے",
                               "کرادی": "کرا دی",
                               "ہوگئی": "ہو گئی",
                               "جارہا": "جا رہا",
                               "ہوجاتے": "ہو جاتے",
                               "اڑادیا": "اڑا دیا",
                               "ہوجائے": "ہو جائے",
                               "کردیے": "کر دیے",
                               "کرسکیں": "کر سکیں",
                               "بتایاہے": "بتایا ہے",
                               "رہاہے": "رہا ہے",
                               "ہےکہ": "ہے کہ",
                               "بالاترہے": "بالاتر ہے",
                               "کہاہے": "کہا ہے",
                               "جاتاہے": "جاتا ہے",
                               "بلایاہے": "بلایا ہے",
                               "جارہاہے": "جا رہا ہے",
                               "دیاہے": "دیا ہے",
                               "ہوگا": "ہو گا",
                               "کیاتھا": "کیا تھا",
                               "کرلی۔": "کر لی۔",
                               "کیاگیا": "کیا گیا",
                               "گیاتھا": "گیا تھا",
                               "کےلئے": "کے لئے",
                               "کےلئے۔": "کے لئے۔",
                               "ہوجانا": "ہو جانا",
                               "گا۔انہوں": "گا۔ انہوں",
                               "کیاجائے": "کیا جائے",
                               "آرہا": "آ رہا",
                               "دیاگیا": "دیا گیا",
                               "ہے۔آپ": "ہے۔ آپ",
                               "کاکہناہے": "کا کہنا ہے",
                               "ہے۔لیکن": "ہے۔ لیکن",
                               "بتایاگیا": "بتایا گیا",
                               "ہے۔ایسے": "ہے۔ ایسے",
                               "ہے۔ترجمان": "ہے۔ ترجمان",
                               "دیکھاجاسکتاہے": "دیکھا جا سکتا ہے",
                               "کامقدمہ": "کا مقدمہ",
                               "نظرآنے": "نظر آنے",
                               "گی۔فلم": "گی۔ فلم",
                               "بوگی": "بو گی",
                               "چھوڑدیں": "چھوڑ دیں",
                               "گا۔ماہرین": "گا۔ ماہرین",
                               "بتاسکتی": "بتا سکتی",
                               "ہے۔بہت": "ہے۔ بہت",
                               "تھے۔جب": "تھے۔ جب",
                               "ہیں۔شاہ": "ہیں۔ شاہ",
                               "گیا۔محکمہ": "گیا۔ محکمہ",
                               "تھے۔لیکن": "تھے۔ لیکن",
                               "تھی۔ذرائع": "تھی۔ ذرائع",
                               "کرلیں۔اس": "کرلیں۔ اس",
                               "ہواہے۔": "ہوا ہے۔",
                               "کرارہے": "کرا رہے",
                               "ہے۔کئی": "ہے۔ کئی",
                               "کرناہو": "کرنا ہو",
                               "کرسکتے": "کر سکتے",
                               "جارہی": "جا رہی",
                               "کہناتھا": "کہنا تھا",
                               "کےلیے": "کے لیے",
                               "کاکہناتھاکہ": "کا کہنا تھا کہ",
                               "جاکر": "جا کر",
                               "کیاہے": "کیا ہے",
                               "کودیا": "کو دیا",
                               "توحکومت": "تو حکومت",
                               "کومعاف": "کو معاف",
                               "کوخبردارکیا": "کو خبردار کیا",
                               "کوجانے": "کو جانے",
                               "کواپنے": "کو اپنے",
                               "اگرکوئی": "اگر کوئی",
                               "کوپھانسی": "کو پھانسی",
                               "کواستعمال": "کو استعمال",
                               "ہےجب": "ہے جب",
                               "رکھاگیا": "رکھا گیا",
                               "دکھایاگیا": "دکھایا گیا",
                               "کےنتیجے": "کے نتیجے",
                               "کیاجاسکتا": "کیا جا سکتا",
                               "تھاکہ": "تھا کہ",
                               "کہاکہ": "کہا کہ",
                               "کےبعد": "کے بعد",
                               "کرکے": "کر کے",
                               "گیاہے": "گیا ہے",
                               "کررہا": "کر رہا",
                               "کاکہنا": "کا کہنا",
                               "ہوتاہے": "ہوتا ہے",
                               "گئےہیں": "گئے ہیں",
                               "آگئے": "آ گئے",
                               "ہوجاتی": "ہو جاتی",
                               "جاسکتا": "جا سکتا",
                               "کرناہے": "کرنا ہے",
                               "ءتک": "ء تک",
                               "ءکی": "ء کی",
                               "ءکے": "ء کے",
                               "آرہے": "آ رہے",
                               "آسکتا": "آ سکتا",
                               "آگئے": "آ گئے",
                               "آئیںگی": "آئیں گی",
                               "آئیےآپ": "آئیے آپ",
                               "آئےروز": "آئے روز",
                               "آباداور": "آباد اور",
                               "آبادسے": "آباد سے",
                               "آبادمیں": "آباد میں",
                               "آبادکی": "آباد کی",
                               "آبادہائی": "آباد ہائی",
                               "آبادیکے": "آبادی کے",
                               "آتاہے": "آتا ہے",
                               "آتےہی": "آتے ہی",
                               "آتےہیں": "آتے ہیں",
                               "آزادعدلیہ": "آزاد عدلیہ",
                               "آسٹریلیاکے": "آسٹریلیا کے",
                               "آغازمیں": "آغاز میں",
                               "آغازکر": "آغاز کر",
                               "آغازکیا": "آغاز کیا",
                               "آفریدینے": "آفریدی نے",
                               "آمدکے": "آمد کے",
                               "آمریتکے": "آمریت کے",
                               "آنکھوںسے": "آنکھوں سے",
                               "آنکھوںکے": "آنکھوں کے",
                               "آنےسے": "آنے سے",
                               "آنےوالا": "آنے والا",
                               "آنےوالی": "آنے والی",
                               "آنےوالے": "آنے والے",
                               "آنےپر": "آنے پر",
                               "آنےکا": "آنے کا",
                               "آنےکے": "آنے کے",
                               "آوازمیں": "آواز میں",
                               "آپاپنی": "آپ اپنی",
                               "آپبھی": "آپ بھی",
                               "آپنے": "آپ نے",
                               "آپکا": "آپ کا",
                               "آپکسی": "آپ کسی",
                               "آڑمیں": "آڑ میں",
                               "آگاہکر": "آگاہ کر",
                               "آگےبڑھ": "آگے بڑھ",
                               "آہستہآہستہ": "آہستہ آہستہ",
                               "آیااور": "آیا اور",
                               "آیاتو": "آیا تو",
                               "آیاکہ": "آیا کہ",
                               "آیاہے": "آیا ہے",
                               "ئیاور": "ئی اور",
                               "ئیایسا": "ئی ایسا",
                               "ئیایسی": "ئی ایسی",
                               "ئےاس": "ئے اس",
                               "ئےاور": "ئے اور",
                               "ئےتا": "ئے تا",
                               "ئےتو": "ئے تو",
                               "ئےجس": "ئے جس",
                               "ئےوقوعہ": "ئے وقوعہ",
                               "ئےکہ": "ئے کہ",
                               "ئےگا": "ئے گا",
                               "ئےگی": "ئے گی",
                               "ابایک": "اب ایک",
                               "اببھی": "اب بھی",
                               "ابہم": "اب ہم",
                               "ابیہ": "اب یہ",
                               "ابتدائیطور": "ابتدائی طور",
                               "ابھیبھی": "ابھی بھی",
                               "ابھیتک": "ابھی تک",
                               "اتفاقرائے": "اتفاق رائے",
                               "اتفاقکیا": "اتفاق کیا",
                               "اتناہی": "اتنا ہی",
                               "اتنیہی": "اتنی ہی",
                               "اتوارکو": "اتوار کو",
                               "اثرانداز": "اثر انداز",
                               "اجازتدی": "اجازت دی",
                               "اجازتدے": "اجازت دے",
                               "اجلاسسے": "اجلاس سے",
                               "اجلاسمیں": "اجلاس میں",
                               "احتجاجکیا": "احتجاج کیا",
                               "احسناقبال": "احسن اقبال",
                               "احمدخان": "احمد خان",
                               "احمدشہزاد": "احمد شہزاد",
                               "اخبارکے": "اخبار کے",
                               "اخباراتمیں": "اخبارات میں",
                               "اختتامپر": "اختتام پر",
                               "اختیارکرنے": "اختیار کرنے",
                               "اختیارکی": "اختیار کی",
                               "اداکرتا": "ادا کرتا",
                               "اداکرنا": "ادا کرنا",
                               "اداکریں": "ادا کریں",
                               "اداکرے": "ادا کرے",
                               "اداکیا": "ادا کیا",
                               "اداروںسے": "اداروں سے",
                               "اداروںنے": "اداروں نے",
                               "ادارےکو": "ادارے کو",
                               "ادارےکی": "ادارے کی",
                               "اداکارہنے": "اداکارہ نے",
                               "اداکاریکے": "اداکاری کے",
                               "اربروپے": "ارب روپے",
                               "اربڈالر": "ارب ڈالر",
                               "اربوںروپے": "اربوں روپے",
                               "ارکاناسمبلی": "ارکان اسمبلی",
                               "ارکاننے": "ارکان نے",
                               "ازجلد": "از جلد",
                               "ازخود": "از خود",
                               "ازوقت": "از وقت",
                               "ازکم": "از کم",
                               "اساقدام": "اس اقدام",
                               "اسبیان": "اس بیان",
                               "اسجنگ": "اس جنگ",
                               "اسجگہ": "اس جگہ",
                               "اسحقیقت": "اس حقیقت",
                               "اسحوالے": "اس حوالے",
                               "اسخبر": "اس خبر",
                               "اسخطہ": "اس خطہ",
                               "اسخطے": "اس خطے",
                               "اسدن": "اس دن",
                               "اسدنیا": "اس دنیا",
                               "اسدور": "اس دور",
                               "اسدوران": "اس دوران",
                               "اسسلسلہ": "اس سلسلہ",
                               "اسسلسلے": "اس سلسلے",
                               "اسسوال": "اس سوال",
                               "اسشہر": "اس شہر",
                               "اسعلاقے": "اس علاقے",
                               "اسقانون": "اس قانون",
                               "اسقدر": "اس قدر",
                               "اسلیئے": "اس لیئے",
                               "اسلیے": "اس لیے",
                               "اسمرتبہ": "اس مرتبہ",
                               "اسمرض": "اس مرض",
                               "اسمعاملے": "اس معاملے",
                               "اسمعاہدے": "اس معاہدے",
                               "اسملک": "اس ملک",
                               "اسمنصوبے": "اس منصوبے",
                               "اسواقعہ": "اس واقعہ",
                               "اسواقعے": "اس واقعے",
                               "اسکام": "اس کام",
                               "اسکتاب": "اس کتاب",
                               "اسکور": "اس کور",
                               "اسکول": "اس کول",
                               "اسکولوں": "اس کولوں",
                               "اسکیس": "اس کیس",
                               "استدعاکی": "استدعا کی",
                               "استعمالنہ": "استعمال نہ",
                               "استعمالنہیں": "استعمال نہیں",
                               "استعمالکر": "استعمال کر",
                               "استعمالکرنا": "استعمال کرنا",
                               "استعمالکرنے": "استعمال کرنے",
                               "استعمالکیا": "استعمال کیا",
                               "استعمالکے": "استعمال کے",
                               "استعمالہو": "استعمال ہو",
                               "استفسارکیا": "استفسار کیا",
                               "اسرائیلاور": "اسرائیل اور",
                               "اسرائیلنے": "اسرائیل نے",
                               "اسرائیلکو": "اسرائیل کو",
                               "اسرائیلکی": "اسرائیل کی",
                               "اسلاماور": "اسلام اور",
                               "اسلاممیں": "اسلام میں",
                               "اسلامکا": "اسلام کا",
                               "اسلامکو": "اسلام کو",
                               "اسلامیجمہوریہ": "اسلامی جمہوریہ",
                               "اسلامیممالک": "اسلامی ممالک",
                               "اسمارٹفون": "اسمارٹ فون",
                               "اسمبلیمیں": "اسمبلی میں",
                               "اسمبلیکے": "اسمبلی کے",
                               "اسپتالمنتقل": "اسپتال منتقل",
                               "اسپتالمیں": "اسپتال میں",
                               "اسیدوران": "اسی دوران",
                               "اسیوجہ": "اسی وجہ",
                               "اسیوقت": "اسی وقت",
                               "اسےاس": "اسے اس",
                               "اسےاپنی": "اسے اپنی",
                               "اسےاپنے": "اسے اپنے",
                               "اسےایک": "اسے ایک",
                               "اشفاقپرویز": "اشفاق پرویز",
                               "اصلمیں": "اصل میں",
                               "اضافہکیا": "اضافہ کیا",
                               "اضافہہو": "اضافہ ہو",
                               "اضافہہوتا": "اضافہ ہوتا",
                               "اضافےکی": "اضافے کی",
                               "اضافےکے": "اضافے کے",
                               "اظہارانہوں": "اظہار انہوں",
                               "اظہارخیال": "اظہار خیال",
                               "اظہارکر": "اظہار کر",
                               "اظہارکیا": "اظہار کیا",
                               "اعتبارسے": "اعتبار سے",
                               "اعترافکر": "اعتراف کر",
                               "اعتزازاحسن": "اعتزاز احسن",
                               "اعتمادمیں": "اعتماد میں",
                               "اعدادو": "اعداد و",
                               "اعزازحاصل": "اعزاز حاصل",
                               "اعظماور": "اعظم اور",
                               "اعظمسے": "اعظم سے",
                               "اعظمشاہد": "اعظم شاہد",
                               "اعظممحمد": "اعظم محمد",
                               "اعظمنواز": "اعظم نواز",
                               "اعظمنے": "اعظم نے",
                               "اعظمپاکستان": "اعظم پاکستان",
                               "اعظمکے": "اعظم کے",
                               "اعظمگیلانی": "اعظم گیلانی",
                               "اعلانکر": "اعلان کر",
                               "اعلانکیا": "اعلان کیا",
                               "اعلیحکام": "اعلی حکام",
                               "اعلیسندھ": "اعلی سندھ",
                               "افرادنے": "افراد نے",
                               "افرادکو": "افراد کو",
                               "افرادکی": "افراد کی",
                               "افرادکے": "افراد کے",
                               "افرادہلاک": "افراد ہلاک",
                               "افریقہکے": "افریقہ کے",
                               "افسرانکو": "افسران کو",
                               "افسوسکا": "افسوس کا",
                               "افغانستاناور": "افغانستان اور",
                               "افغانستانمیں": "افغانستان میں",
                               "افغانستانکی": "افغانستان کی",
                               "افغانستانکے": "افغانستان کے",
                               "افواجکی": "افواج کی",
                               "افواجکے": "افواج کے",
                               "اقبالکے": "اقبال کے",
                               "اقتدارکی": "اقتدار کی",
                               "اقداماتکئے": "اقدامات کئے",
                               "الحقنے": "الحق نے",
                               "الزاملگایا": "الزام لگایا",
                               "الزاماتکی": "الزامات کی",
                               "القاعدہکے": "القاعدہ کے",
                               "الگالگ": "الگ الگ",
                               "الیونکے": "الیون کے",
                               "الیکشنکمیشن": "الیکشن کمیشن",
                               "امانکی": "امان کی",
                               "امتمسلمہ": "امت مسلمہ",
                               "امدادکی": "امداد کی",
                               "امدادکے": "امداد کے",
                               "امرکی": "امر کی",
                               "امراضقلب": "امراض قلب",
                               "امراضکا": "امراض کا",
                               "امریکااور": "امریکا اور",
                               "امریکانے": "امریکا نے",
                               "امریکاکو": "امریکا کو",
                               "امریکہاور": "امریکہ اور",
                               "امریکہمیں": "امریکہ میں",
                               "امریکہنے": "امریکہ نے",
                               "امریکہپاکستان": "امریکہ پاکستان",
                               "امریکہکو": "امریکہ کو",
                               "امریکہکی": "امریکہ کی",
                               "امریکہکے": "امریکہ کے",
                               "امریکیحکام": "امریکی حکام",
                               "امریکیحکومت": "امریکی حکومت",
                               "امریکیریاست": "امریکی ریاست",
                               "امریکیسفیر": "امریکی سفیر",
                               "امریکیصدر": "امریکی صدر",
                               "امریکیفوج": "امریکی فوج",
                               "امریکیفوجی": "امریکی فوجی",
                               "امریکیمفادات": "امریکی مفادات",
                               "امنو": "امن و",
                               "امنکی": "امن کی",
                               "امنکے": "امن کے",
                               "امورپر": "امور پر",
                               "امکانہے": "امکان ہے",
                               "انافراد": "ان افراد",
                               "انحالات": "ان حالات",
                               "انعلاقوں": "ان علاقوں",
                               "انلوگوں": "ان لوگوں",
                               "انممالک": "ان ممالک",
                               "اننے": "ان نے",
                               "انپر": "ان پر",
                               "انکار": "ان کار",
                               "انکیلئے": "ان کیلئے",
                               "انہی": "ان ہی",
                               "انائیکی": "انائی کی",
                               "انتخابمیں": "انتخاب میں",
                               "انتخاباتمیں": "انتخابات میں",
                               "انتخابیمہم": "انتخابی مہم",
                               "انتظارکر": "انتظار کر",
                               "انتظامیہکو": "انتظامیہ کو",
                               "انتظامیہکی": "انتظامیہ کی",
                               "انتظامیہکے": "انتظامیہ کے",
                               "انتہاپسند": "انتہا پسند",
                               "انتہاپسندی": "انتہا پسندی",
                               "انتہائیاہم": "انتہائی اہم",
                               "انجامدے": "انجام دے",
                               "اندازسے": "انداز سے",
                               "اندازمیں": "انداز میں",
                               "اندازکر": "انداز کر",
                               "اندرسے": "اندر سے",
                               "انسانکے": "انسان کے",
                               "انقلابکی": "انقلاب کی",
                               "انوںکو": "انوں کو",
                               "انوںکی": "انوں کی",
                               "انوںکے": "انوں کے",
                               "انگلینڈکے": "انگلینڈ کے",
                               "انہیںاپنی": "انہیں اپنی",
                               "انہیںاپنے": "انہیں اپنے",
                               "انہیںیہ": "انہیں یہ",
                               "انینے": "انی نے",
                               "انےکا": "انے کا",
                               "انےکی": "انے کی",
                               "انےکے": "انے کے",
                               "اوبامانے": "اوباما نے",
                               "اوبامہنے": "اوبامہ نے",
                               "اورآئندہ": "اور آئندہ",
                               "اورآئی": "اور آئی",
                               "اورآپ": "اور آپ",
                               "اوراسرائیل": "اور اسرائیل",
                               "اوراسی": "اور اسی",
                               "اوراسے": "اور اسے",
                               "اورامریکا": "اور امریکا",
                               "اورانسانی": "اور انسانی",
                               "اورانہوں": "اور انہوں",
                               "اورانہیں": "اور انہیں",
                               "اوراپنی": "اور اپنی",
                               "اوراپنے": "اور اپنے",
                               "اوراگر": "اور اگر",
                               "اورایران": "اور ایران",
                               "اورایسے": "اور ایسے",
                               "اوربرطانیہ": "اور برطانیہ",
                               "اوربعد": "اور بعد",
                               "اوربعض": "اور بعض",
                               "اوربلوچستان": "اور بلوچستان",
                               "اوربچوں": "اور بچوں",
                               "اوربھارت": "اور بھارت",
                               "اوربے": "اور بے",
                               "اورتو": "اور تو",
                               "اورتین": "اور تین",
                               "اورجب": "اور جب",
                               "اورجمہوریت": "اور جمہوریت",
                               "اورجنوبی": "اور جنوبی",
                               "اورحکومتی": "اور حکومتی",
                               "اورخشک": "اور خشک",
                               "اورخواتین": "اور خواتین",
                               "اوردل": "اور دل",
                               "اورزخمی": "اور زخمی",
                               "اورزیادہ": "اور زیادہ",
                               "اورسابق": "اور سابق",
                               "اورسماجی": "اور سماجی",
                               "اورسندھ": "اور سندھ",
                               "اورسی": "اور سی",
                               "اورسے": "اور سے",
                               "اورصحت": "اور صحت",
                               "اورصدر": "اور صدر",
                               "اورصوبائی": "اور صوبائی",
                               "اورطالبان": "اور طالبان",
                               "اورعالمی": "اور عالمی",
                               "اورعدلیہ": "اور عدلیہ",
                               "اورعوام": "اور عوام",
                               "اورعوامی": "اور عوامی",
                               "اورلوگ": "اور لوگ",
                               "اورلوگوں": "اور لوگوں",
                               "اورمتعدد": "اور متعدد",
                               "اورمجھے": "اور مجھے",
                               "اورمختلف": "اور مختلف",
                               "اورمذہبی": "اور مذہبی",
                               "اورمسلمانوں": "اور مسلمانوں",
                               "اورمعاشی": "اور معاشی",
                               "اورملک": "اور ملک",
                               "اورمیرے": "اور میرے",
                               "اورمیڈیا": "اور میڈیا",
                               "اورمیں": "اور میں",
                               "اوروزیر": "اور وزیر",
                               "اورپانی": "اور پانی",
                               "اورپاکستان": "اور پاکستان",
                               "اورپر": "اور پر",
                               "اورپنجاب": "اور پنجاب",
                               "اورپی": "اور پی",
                               "اورپیپلز": "اور پیپلز",
                               "اورکس": "اور کس",
                               "اورکشمیر": "اور کشمیر",
                               "اورکو": "اور کو",
                               "اورکہا": "اور کہا",
                               "اورکے": "اور کے",
                               "اورہر": "اور ہر",
                               "اورہم": "اور ہم",
                               "اورہماری": "اور ہماری",
                               "اورہمیں": "اور ہمیں",
                               "اوریوں": "اور یوں",
                               "اوریہاں": "اور یہاں",
                               "اوقاتمیں": "اوقات میں",
                               "اوورزمیں": "اوورز میں",
                               "اوپرسے": "اوپر سے",
                               "اٹھکر": "اٹھ کر",
                               "اپڈیٹ": "اپ ڈیٹ",
                               "اپریلکو": "اپریل کو",
                               "اپناکام": "اپنا کام",
                               "اپناکردار": "اپنا کردار",
                               "اپنیاس": "اپنی اس",
                               "اپنیاپنی": "اپنی اپنی",
                               "اپنیایک": "اپنی ایک",
                               "اپنیبیوی": "اپنی بیوی",
                               "اپنیبیٹی": "اپنی بیٹی",
                               "اپنیجان": "اپنی جان",
                               "اپنیجگہ": "اپنی جگہ",
                               "اپنیحکومت": "اپنی حکومت",
                               "اپنیذمہ": "اپنی ذمہ",
                               "اپنیرپورٹ": "اپنی رپورٹ",
                               "اپنیمرضی": "اپنی مرضی",
                               "اپنینئی": "اپنی نئی",
                               "اپنیپارٹی": "اپنی پارٹی",
                               "اپنیکتاب": "اپنی کتاب",
                               "اپنےآپ": "اپنے آپ",
                               "اپنےاندر": "اپنے اندر",
                               "اپنےبیان": "اپنے بیان",
                               "اپنےبیٹے": "اپنے بیٹے",
                               "اپنےشوہر": "اپنے شوہر",
                               "اپنےلئے": "اپنے لئے",
                               "اپنےمفادات": "اپنے مفادات",
                               "اپنےنام": "اپنے نام",
                               "اپنےوالد": "اپنے والد",
                               "اپنےگھروں": "اپنے گھروں",
                               "اپنےہاتھ": "اپنے ہاتھ",
                               "اپنےہاتھوں": "اپنے ہاتھوں",
                               "اپوزیشنلیڈر": "اپوزیشن لیڈر",
                               "اچھیطرح": "اچھی طرح",
                               "اکتوبرء": "اکتوبر ء",
                               "اکتوبرکو": "اکتوبر کو",
                               "اگرایسا": "اگر ایسا",
                               "اگرحکومت": "اگر حکومت",
                               "اگرپاکستان": "اگر پاکستان",
                               "اگرکو": "اگر کو",
                               "اگستکو": "اگست کو",
                               "اہتمامکیا": "اہتمام کیا",
                               "اہلکاروںنے": "اہلکاروں نے",
                               "اہلکاروںکو": "اہلکاروں کو",
                               "اہلکاروںکی": "اہلکاروں کی",
                               "اہمہے": "اہم ہے",
                               "اہمیتکا": "اہمیت کا",
                               "ایسی": "ای سی",
                               "ایمیل": "ای میل",
                               "ایئرپورٹ": "ایئر پورٹ",
                               "ایئرپورٹپر": "ایئرپورٹ پر",
                               "ایانعلی": "ایان علی",
                               "ایبٹآباد": "ایبٹ آباد",
                               "ایجنسیمیں": "ایجنسی میں",
                               "ایجنسیکے": "ایجنسی کے",
                               "ایراننے": "ایران نے",
                               "ایرانکی": "ایران کی",
                               "ایرانکے": "ایران کے",
                               "ایسایچ": "ایس ایچ",
                               "ایسٹی": "ایس ٹی",
                               "ایسپی": "ایس پی",
                               "ایسالگتا": "ایسا لگتا",
                               "ایسانہ": "ایسا نہ",
                               "ایساکرنے": "ایسا کرنے",
                               "ایساہو": "ایسا ہو",
                               "ایسیصورت": "ایسی صورت",
                               "ایسےافراد": "ایسے افراد",
                               "ایسےلوگ": "ایسے لوگ",
                               "ایسےلوگوں": "ایسے لوگوں",
                               "ایسےوقت": "ایسے وقت",
                               "ایشنکے": "ایشن کے",
                               "ایفآئی": "ایف آئی",
                               "ایفبی": "ایف بی",
                               "ایلمیں": "ایل میں",
                               "ایلکے": "ایل کے",
                               "ایمایس": "ایم ایس",
                               "ایمایم": "ایم ایم",
                               "ایماین": "ایم این",
                               "ایمپی": "ایم پی",
                               "ایمکیو": "ایم کیو",
                               "اینآر": "این آر",
                               "ایناے": "این اے",
                               "ایوانمیں": "ایوان میں",
                               "ایوبخان": "ایوب خان",
                               "ایٹمبم": "ایٹم بم",
                               "ایٹمیپروگرام": "ایٹمی پروگرام",
                               "ایٹمیہتھیاروں": "ایٹمی ہتھیاروں",
                               "ایپلیکیشن": "ایپلی کیشن",
                               "ایچاو": "ایچ او",
                               "ایکارب": "ایک ارب",
                               "ایکامریکی": "ایک امریکی",
                               "ایکانتہائی": "ایک انتہائی",
                               "ایکانٹرویو": "ایک انٹرویو",
                               "ایکاور": "ایک اور",
                               "ایکایسا": "ایک ایسا",
                               "ایکایسی": "ایک ایسی",
                               "ایکبات": "ایک بات",
                               "ایکبار": "ایک بار",
                               "ایکبڑا": "ایک بڑا",
                               "ایکبڑے": "ایک بڑے",
                               "ایکبھی": "ایک بھی",
                               "ایکتصویر": "ایک تصویر",
                               "ایکتقریب": "ایک تقریب",
                               "ایکخاص": "ایک خاص",
                               "ایکدفعہ": "ایک دفعہ",
                               "ایکدن": "ایک دن",
                               "ایکروز": "ایک روز",
                               "ایکروزہ": "ایک روزہ",
                               "ایکرپورٹ": "ایک رپورٹ",
                               "ایکسال": "ایک سال",
                               "ایکسالہ": "ایک سالہ",
                               "ایکسے": "ایک سے",
                               "ایکشخص": "ایک شخص",
                               "ایکطرف": "ایک طرف",
                               "ایکطویل": "ایک طویل",
                               "ایکعام": "ایک عام",
                               "ایکغیر": "ایک غیر",
                               "ایکنئے": "ایک نئے",
                               "ایکنجی": "ایک نجی",
                               "ایکنوجو": "ایک نوجو",
                               "ایکنیا": "ایک نیا",
                               "بابراعوان": "بابر اعوان",
                               "باتتو": "بات تو",
                               "باتنہیں": "بات نہیں",
                               "باتپر": "بات پر",
                               "باتچیت": "بات چیت",
                               "باتکا": "بات کا",
                               "باتکرنے": "بات کرنے",
                               "باتکی": "بات کی",
                               "باتہے": "بات ہے",
                               "باتیہ": "بات یہ",
                               "باتیںکر": "باتیں کر",
                               "باربار": "بار بار",
                               "بارپھر": "بار پھر",
                               "بارشکا": "بارش کا",
                               "بارشکے": "بارش کے",
                               "بازارمیں": "بازار میں",
                               "باعثبن": "باعث بن",
                               "باغڈیم": "باغ ڈیم",
                               "باقاعدگیسے": "باقاعدگی سے",
                               "باقیہے": "باقی ہے",
                               "بالوںکو": "بالوں کو",
                               "بالوںکی": "بالوں کی",
                               "بالیووڈ": "بالی ووڈ",
                               "بالیوڈ": "بالی وڈ",
                               "باوجودبھی": "باوجود بھی",
                               "باپکی": "باپ کی",
                               "باپکے": "باپ کے",
                               "باہرنکل": "باہر نکل",
                               "باہرہو": "باہر ہو",
                               "بتایاتھا": "بتایا تھا",
                               "بجائے": "بجا ئے",
                               "بجلیپیدا": "بجلی پیدا",
                               "بجلیکا": "بجلی کا",
                               "بجلیکی": "بجلی کی",
                               "بجٹمیں": "بجٹ میں",
                               "بجےتک": "بجے تک",
                               "بحالکر": "بحال کر",
                               "بحالہو": "بحال ہو",
                               "بحالیکے": "بحالی کے",
                               "بحرانسے": "بحران سے",
                               "بحقاور": "بحق اور",
                               "بدقسمتی": "بد قسمتی",
                               "بدھکو": "بدھ کو",
                               "براکاوباما": "براک اوباما",
                               "براہراست": "براہ راست",
                               "برداشتنہیں": "برداشت نہیں",
                               "برسسے": "برس سے",
                               "برسکی": "برس کی",
                               "برسوںسے": "برسوں سے",
                               "برسوںمیں": "برسوں میں",
                               "برطانویاخبار": "برطانوی اخبار",
                               "برطانویوزیر": "برطانوی وزیر",
                               "برطانیہکی": "برطانیہ کی",
                               "برقراررکھنے": "برقرار رکھنے",
                               "بروئےکار": "بروئے کار",
                               "بصیرتمیاں": "بصیرت میاں",
                               "بعداس": "بعد اس",
                               "بعداسے": "بعد اسے",
                               "بعدانہوں": "بعد انہوں",
                               "بعدانہیں": "بعد انہیں",
                               "بعدمیں": "بعد میں",
                               "بعدپاکستان": "بعد پاکستان",
                               "بعضاوقات": "بعض اوقات",
                               "بلکی": "بل کی",
                               "بلاولبھٹو": "بلاول بھٹو",
                               "بلندہو": "بلند ہو",
                               "بلکہاس": "بلکہ اس",
                               "بلکہوہ": "بلکہ وہ",
                               "بلیکواٹر": "بلیک واٹر",
                               "بمدھماکوں": "بم دھماکوں",
                               "بمدھماکے": "بم دھماکے",
                               "بنجا": "بن جا",
                               "بنجائیں": "بن جائیں",
                               "بنجاتا": "بن جاتا",
                               "بنجاتی": "بن جاتی",
                               "بنسکتی": "بن سکتی",
                               "بنسکتے": "بن سکتے",
                               "بنچکی": "بن چکی",
                               "بنچکے": "بن چکے",
                               "بنکر": "بن کر",
                               "بنادیا": "بنا دیا",
                               "بنارہے": "بنا رہے",
                               "بنالیا": "بنا لیا",
                               "بناکر": "بنا کر",
                               "بناہوا": "بنا ہوا",
                               "بناءپر": "بناء پر",
                               "بنائیگئی": "بنائی گئی",
                               "بنائیںگے": "بنائیں گے",
                               "بنائےگئے": "بنائے گئے",
                               "بناتاہے": "بناتا ہے",
                               "بناتےہوئے": "بناتے ہوئے",
                               "بناتےہیں": "بناتے ہیں",
                               "بنانےوالے": "بنانے والے",
                               "بنانےپر": "بنانے پر",
                               "بنانےکی": "بنانے کی",
                               "بنانےکے": "بنانے کے",
                               "بنایاتھا": "بنایا تھا",
                               "بنایاگیا": "بنایا گیا",
                               "بنایاہے": "بنایا ہے",
                               "بنتیہے": "بنتی ہے",
                               "بنتےہیں": "بنتے ہیں",
                               "بندکر": "بند کر",
                               "بندیکر": "بندی کر",
                               "بندیکی": "بندی کی",
                               "بندیکے": "بندی کے",
                               "بننےوالی": "بننے والی",
                               "بننےوالے": "بننے والے",
                               "بننےکا": "بننے کا",
                               "بننےکی": "بننے کی",
                               "بننےکے": "بننے کے",
                               "بنچنے": "بنچ نے",
                               "بنگلہدیش": "بنگلہ دیش",
                               "بنیہوئی": "بنی ہوئی",
                               "بنیادپر": "بنیاد پر",
                               "بنےگا": "بنے گا",
                               "بنےہوئے": "بنے ہوئے",
                               "بورڈنے": "بورڈ نے",
                               "بچانےکی": "بچانے کی",
                               "بچانےکیلئے": "بچانے کیلئے",
                               "بچنےکے": "بچنے کے",
                               "بچوںکا": "بچوں کا",
                               "بچوںکو": "بچوں کو",
                               "بچوںکی": "بچوں کی",
                               "بچوںکے": "بچوں کے",
                               "بچیکو": "بچی کو",
                               "بچےکے": "بچے کے",
                               "بڑھجاتا": "بڑھ جاتا",
                               "بڑھرہا": "بڑھ رہا",
                               "بڑھکر": "بڑھ کر",
                               "بڑھاکر": "بڑھا کر",
                               "بڑھانےکے": "بڑھانے کے",
                               "بڑھتیہوئی": "بڑھتی ہوئی",
                               "بڑھتےہوئے": "بڑھتے ہوئے",
                               "بڑیتعداد": "بڑی تعداد",
                               "بڑیوجہ": "بڑی وجہ",
                               "بڑےپیمانے": "بڑے پیمانے",
                               "بککے": "بک کے",
                               "بھارتمیں": "بھارت میں",
                               "بھارتنے": "بھارت نے",
                               "بھارتپاکستان": "بھارت پاکستان",
                               "بھارتکو": "بھارت کو",
                               "بھارتکی": "بھارت کی",
                               "بھارتیحکومت": "بھارتی حکومت",
                               "بھرکی": "بھر کی",
                               "بھرکے": "بھر کے",
                               "بھٹوزرداری": "بھٹو زرداری",
                               "بھٹونے": "بھٹو نے",
                               "بھٹوکو": "بھٹو کو",
                               "بھیآپ": "بھی آپ",
                               "بھیاستعمال": "بھی استعمال",
                               "بھیان": "بھی ان",
                               "بھیانک": "بھی انک",
                               "بھیاور": "بھی اور",
                               "بہتربنانے": "بہتر بنانے",
                               "بہترہو": "بہتر ہو",
                               "بیآئی": "بی آئی",
                               "بیآر": "بی آر",
                               "بیانپر": "بیان پر",
                               "بیانکر": "بیان کر",
                               "بیانکی": "بیان کی",
                               "بیتالمقدس": "بیت المقدس",
                               "بیرونملک": "بیرون ملک",
                               "بیشترعلاقوں": "بیشتر علاقوں",
                               "بیماریوںسے": "بیماریوں سے",
                               "بینالاقوامی": "بین الاقوامی",
                               "بینظیربھٹو": "بینظیر بھٹو",
                               "بیٹےکو": "بیٹے کو",
                               "بیٹےکی": "بیٹے کی",
                               "بےبس": "بے بس",
                               "بےبسی": "بے بسی",
                               "بےبنیاد": "بے بنیاد",
                               "بےجا": "بے جا",
                               "بےحسی": "بے حسی",
                               "بےروزگاری": "بے روزگاری",
                               "بےشک": "بے شک",
                               "بےنظیر": "بے نظیر",
                               "بےنقاب": "بے نقاب",
                               "بےپناہ": "بے پناہ",
                               "بےچینی": "بے چینی",
                               "بےگھر": "بے گھر",
                               "تازہترین": "تازہ ترین",
                               "تاہماس": "تاہم اس",
                               "تاہمان": "تاہم ان",
                               "تاہموہ": "تاہم وہ",
                               "تاہمیہ": "تاہم یہ",
                               "تببھی": "تب بھی",
                               "تبادلہخیال": "تبادلہ خیال",
                               "تباہکر": "تباہ کر",
                               "تباہکن": "تباہ کن",
                               "تباہیکے": "تباہی کے",
                               "تبدیلکرنے": "تبدیل کرنے",
                               "تبدیلہو": "تبدیل ہو",
                               "تبدیلیکا": "تبدیلی کا",
                               "تبدیلیکی": "تبدیلی کی",
                               "تبدیلیکے": "تبدیلی کے",
                               "تجویزدی": "تجویز دی",
                               "تحریکآزادی": "تحریک آزادی",
                               "تحریکطالبان": "تحریک طالبان",
                               "تحریکپاکستان": "تحریک پاکستان",
                               "تحریککے": "تحریک کے",
                               "تحسینپیش": "تحسین پیش",
                               "تحفظفراہم": "تحفظ فراہم",
                               "تحفظکے": "تحفظ کے",
                               "تردیدکر": "تردید کر",
                               "ترقیاور": "ترقی اور",
                               "ترقیکا": "ترقی کا",
                               "ترقیکی": "ترقی کی",
                               "ترقییافتہ": "ترقی یافتہ",
                               "ترمیمکی": "ترمیم کی",
                               "ترککر": "ترک کر",
                               "ترکیکے": "ترکی کے",
                               "تسلیمکر": "تسلیم کر",
                               "تسلیمکرنے": "تسلیم کرنے",
                               "تسلیمکیا": "تسلیم کیا",
                               "تشددکا": "تشدد کا",
                               "تشددکے": "تشدد کے",
                               "تشویشکا": "تشویش کا",
                               "تصدیقکر": "تصدیق کر",
                               "تصویرمیں": "تصویر میں",
                               "تعالینے": "تعالی نے",
                               "تعاونسے": "تعاون سے",
                               "تعدادمیں": "تعداد میں",
                               "تعلقرکھنے": "تعلق رکھنے",
                               "تعلقنہیں": "تعلق نہیں",
                               "تعلقاتمیں": "تعلقات میں",
                               "تعلقاتکو": "تعلقات کو",
                               "تعلیمحاصل": "تعلیم حاصل",
                               "تعلیمکا": "تعلیم کا",
                               "تعلیمیافتہ": "تعلیم یافتہ",
                               "تعلیمیاداروں": "تعلیمی اداروں",
                               "تقریباایک": "تقریبا ایک",
                               "تمامسیاسی": "تمام سیاسی",
                               "تنظیمکے": "تنظیم کے",
                               "تنظیموںکے": "تنظیموں کے",
                               "تنقیدکی": "تنقید کی",
                               "توآج": "تو آج",
                               "توآپ": "تو آپ",
                               "تواب": "تو اب",
                               "تواسے": "تو اسے",
                               "توامریکہ": "تو امریکہ",
                               "توان": "تو ان",
                               "تواپنی": "تو اپنی",
                               "توایسا": "تو ایسا",
                               "توایسے": "تو ایسے",
                               "توبھی": "تو بھی",
                               "توخود": "تو خود",
                               "توسب": "تو سب",
                               "توشاید": "تو شاید",
                               "توصرف": "تو صرف",
                               "تومجھے": "تو مجھے",
                               "تومیں": "تو میں",
                               "تونہ": "تو نہ",
                               "تونہیں": "تو نہیں",
                               "تونے": "تو نے",
                               "تووہاں": "تو وہاں",
                               "توپہلے": "تو پہلے",
                               "توکبھی": "تو کبھی",
                               "توکو": "تو کو",
                               "توکچھ": "تو کچھ",
                               "توکیا": "تو کیا",
                               "توہر": "تو ہر",
                               "توہم": "تو ہم",
                               "توہمارے": "تو ہمارے",
                               "توہمیں": "تو ہمیں",
                               "توہو": "تو ہو",
                               "توہے": "تو ہے",
                               "تویہی": "تو یہی",
                               "توقعہے": "توقع ہے",
                               "توہینرسالت": "توہین رسالت",
                               "توہینعدالت": "توہین عدالت",
                               "تکان": "تک ان",
                               "تکمحدود": "تک محدود",
                               "تکملتوی": "تک ملتوی",
                               "تکنہ": "تک نہ",
                               "تکوہ": "تک وہ",
                               "تکپہنچا": "تک پہنچا",
                               "تکپہنچانے": "تک پہنچانے",
                               "تکپہنچنے": "تک پہنچنے",
                               "تککسی": "تک کسی",
                               "تککم": "تک کم",
                               "تککو": "تک کو",
                               "تککی": "تک کی",
                               "تککے": "تک کے",
                               "تکیہ": "تک یہ",
                               "تکلیفدہ": "تکلیف دہ",
                               "تھاجس": "تھا جس",
                               "تھالیکن": "تھا لیکن",
                               "تھوڑیدیر": "تھوڑی دیر",
                               "تھیاور": "تھی اور",
                               "تھیتاہم": "تھی تاہم",
                               "تھیںکہ": "تھیں کہ",
                               "تھےتاہم": "تھے تاہم",
                               "تھےمگر": "تھے مگر",
                               "تھےکہ": "تھے کہ",
                               "تیہے": "تی ہے",
                               "تیارکردہ": "تیار کردہ",
                               "تیارکرنے": "تیار کرنے",
                               "تیارکی": "تیار کی",
                               "تیارہو": "تیار ہو",
                               "تیارہے": "تیار ہے",
                               "تیزیسے": "تیزی سے",
                               "تیندن": "تین دن",
                               "تینسو": "تین سو",
                               "تینماہ": "تین ماہ",
                               "تےاور": "تے اور",
                               "تےتھے": "تے تھے",
                               "تےرہتے": "تے رہتے",
                               "تےرہیں": "تے رہیں",
                               "تےرہے": "تے رہے",
                               "تےہوئے": "تے ہوئے",
                               "ثابتنہیں": "ثابت نہیں",
                               "ثابتکرنے": "ثابت کرنے",
                               "ثابتہو": "ثابت ہو",
                               "ثابتہوا": "ثابت ہوا",
                               "ثابتہوتی": "ثابت ہوتی",
                               "ثاقبنثار": "ثاقب نثار",
                               "ثانیہمرزا": "ثانیہ مرزا",
                               "ثبوتہے": "ثبوت ہے",
                               "ثناءاللہ": "ثناء اللہ",
                               "جارہے": "جا رہے",
                               "جاسکتی": "جا سکتی",
                               "جاسکے": "جا سکے",
                               "جاچکا": "جا چکا",
                               "جاچکے": "جا چکے",
                               "جائزہلینے": "جائزہ لینے",
                               "جائزہلے": "جائزہ لے",
                               "جاتاتو": "جاتا تو",
                               "جاتارہا": "جاتا رہا",
                               "جاتیتھی": "جاتی تھی",
                               "جاتیہیں": "جاتی ہیں",
                               "جاتےتھے": "جاتے تھے",
                               "جاتےہوئے": "جاتے ہوئے",
                               "جاریبیان": "جاری بیان",
                               "جاریرکھا": "جاری رکھا",
                               "جاریرکھنے": "جاری رکھنے",
                               "جاریرکھیں": "جاری رکھیں",
                               "جاریرکھے": "جاری رکھے",
                               "جاریرہا": "جاری رہا",
                               "جاریرہے": "جاری رہے",
                               "جاریکئے": "جاری کئے",
                               "جاریکر": "جاری کر",
                               "جاریکردہ": "جاری کردہ",
                               "جاریکرنے": "جاری کرنے",
                               "جاریکیے": "جاری کیے",
                               "جاریہو": "جاری ہو",
                               "جاریہے": "جاری ہے",
                               "جاسکتےہیں": "جاسکتے ہیں",
                               "جانلیوا": "جان لیوا",
                               "جاناچاہئے": "جانا چاہئے",
                               "جاناچاہیے": "جانا چاہیے",
                               "جانتاہے": "جانتا ہے",
                               "جانتےہیں": "جانتے ہیں",
                               "جانینقصان": "جانی نقصان",
                               "جانےوالی": "جانے والی",
                               "جانےوالے": "جانے والے",
                               "جانےکا": "جانے کا",
                               "جانےکی": "جانے کی",
                               "جانےکے": "جانے کے",
                               "جاویداقبال": "جاوید اقبال",
                               "جاویدہاشمی": "جاوید ہاشمی",
                               "جاچکاہے": "جاچکا ہے",
                               "جاںبحق": "جاں بحق",
                               "جبتک": "جب تک",
                               "جبسے": "جب سے",
                               "جبوہ": "جب وہ",
                               "جبہم": "جب ہم",
                               "ججزکی": "ججز کی",
                               "ججوںکی": "ججوں کی",
                               "جدیدترین": "جدید ترین",
                               "جرائمپیشہ": "جرائم پیشہ",
                               "جرممیں": "جرم میں",
                               "جسطرح": "جس طرح",
                               "جسکیلئے": "جس کیلئے",
                               "جسمسے": "جسم سے",
                               "جسممیں": "جسم میں",
                               "جسمپر": "جسم پر",
                               "جسمکا": "جسم کا",
                               "جسٹسآف": "جسٹس آف",
                               "جسٹسثاقب": "جسٹس ثاقب",
                               "جلداز": "جلد از",
                               "جلدکو": "جلد کو",
                               "جلدکے": "جلد کے",
                               "جماعتوںنے": "جماعتوں نے",
                               "جماعتوںکو": "جماعتوں کو",
                               "جماعتوںکی": "جماعتوں کی",
                               "جمعکر": "جمع کر",
                               "جمعہو": "جمع ہو",
                               "جمعراتکو": "جمعرات کو",
                               "جمعہکو": "جمعہ کو",
                               "جمعہکے": "جمعہ کے",
                               "جموںو": "جموں و",
                               "جمہوریحکومت": "جمہوری حکومت",
                               "جمہورینظام": "جمہوری نظام",
                               "جمہوریتکا": "جمہوریت کا",
                               "جمہوریتکو": "جمہوریت کو",
                               "جنلوگوں": "جن لوگوں",
                               "جنکا": "جن کا",
                               "جنکی": "جن کی",
                               "جنکے": "جن کے",
                               "جنرلاشفاق": "جنرل اشفاق",
                               "جنرلر": "جنرل ر",
                               "جنرلراحیل": "جنرل راحیل",
                               "جنرلمشرف": "جنرل مشرف",
                               "جنرلپرویز": "جنرل پرویز",
                               "جنرلکی": "جنرل کی",
                               "جنوبیایشیا": "جنوبی ایشیا",
                               "جنوبیوزیرستان": "جنوبی وزیرستان",
                               "جنوبیپنجاب": "جنوبی پنجاب",
                               "جنوبیکوریا": "جنوبی کوریا",
                               "جنوریء": "جنوری ء",
                               "جنوریکو": "جنوری کو",
                               "جنگسے": "جنگ سے",
                               "جنگمیں": "جنگ میں",
                               "جنگکا": "جنگ کا",
                               "جنگکی": "جنگ کی",
                               "جنھوںنے": "جنھوں نے",
                               "جنہوںنے": "جنہوں نے",
                               "جوآج": "جو آج",
                               "جواب": "جو اب",
                               "جواس": "جو اس",
                               "جوانوں": "جو انوں",
                               "جوانی": "جو انی",
                               "جواپنی": "جو اپنی",
                               "جوپاکستان": "جو پاکستان",
                               "جوپہلے": "جو پہلے",
                               "جوکسی": "جو کسی",
                               "جوکچھ": "جو کچھ",
                               "جوہر": "جو ہر",
                               "جوابدیتے": "جواب دیتے",
                               "جوابدینے": "جواب دینے",
                               "جوابدے": "جواب دے",
                               "جوابمیں": "جواب میں",
                               "جوابنہیں": "جواب نہیں",
                               "جونکو": "جون کو",
                               "جگہوںپر": "جگہوں پر",
                               "جہازمیں": "جہاز میں",
                               "جہازکے": "جہاز کے",
                               "جہانگیرترین": "جہانگیر ترین",
                               "جہاںان": "جہاں ان",
                               "جہاںوہ": "جہاں وہ",
                               "جیہاں": "جی ہاں",
                               "جیتکر": "جیت کر",
                               "جیسےہی": "جیسے ہی",
                               "جیلوںمیں": "جیلوں میں",
                               "جےآئی": "جے آئی",
                               "جےپی": "جے پی",
                               "حادثےمیں": "حادثے میں",
                               "حادثےکے": "حادثے کے",
                               "حاصلکئے": "حاصل کئے",
                               "حاصلکر": "حاصل کر",
                               "حاصلکرنا": "حاصل کرنا",
                               "حاصلکرنے": "حاصل کرنے",
                               "حاصلکی": "حاصل کی",
                               "حاصلہے": "حاصل ہے",
                               "حالکا": "حال کا",
                               "حالکو": "حال کو",
                               "حالکے": "حال کے",
                               "حالہی": "حال ہی",
                               "حالہے": "حال ہے",
                               "حالاتسے": "حالات سے",
                               "حالاتمیں": "حالات میں",
                               "حالاتکا": "حالات کا",
                               "حالاتکے": "حالات کے",
                               "حالتمیں": "حالت میں",
                               "حامدکرزئی": "حامد کرزئی",
                               "حاملہے": "حامل ہے",
                               "حدتک": "حد تک",
                               "حدسے": "حد سے",
                               "حدودمیں": "حدود میں",
                               "حزباختلاف": "حزب اختلاف",
                               "حسابسے": "حساب سے",
                               "حسنیمبارک": "حسنی مبارک",
                               "حسیننواز": "حسین نواز",
                               "حسینکے": "حسین کے",
                               "حصولکے": "حصول کے",
                               "حصوںمیں": "حصوں میں",
                               "حصہبن": "حصہ بن",
                               "حصہلیا": "حصہ لیا",
                               "حصہلینے": "حصہ لینے",
                               "حصہلے": "حصہ لے",
                               "حصہنہیں": "حصہ نہیں",
                               "حصہہیں": "حصہ ہیں",
                               "حضورص": "حضور ص",
                               "حفاظتکے": "حفاظت کے",
                               "حقمیں": "حق میں",
                               "حقہے": "حق ہے",
                               "حقیقتسے": "حقیقت سے",
                               "حقیقتیہ": "حقیقت یہ",
                               "حلنہیں": "حل نہیں",
                               "حلکر": "حل کر",
                               "حلکیلئے": "حل کیلئے",
                               "حلکے": "حل کے",
                               "حلہو": "حل ہو",
                               "حلقوںمیں": "حلقوں میں",
                               "حمایتحاصل": "حمایت حاصل",
                               "حمایتکر": "حمایت کر",
                               "حمایتکی": "حمایت کی",
                               "حملوںسے": "حملوں سے",
                               "حملوںکا": "حملوں کا",
                               "حملہآوروں": "حملہ آوروں",
                               "حملہکرنے": "حملہ کرنے",
                               "حملےکا": "حملے کا",
                               "حوصلہافزائی": "حوصلہ افزائی",
                               "حکامسے": "حکام سے",
                               "حکامنے": "حکام نے",
                               "حکامکی": "حکام کی",
                               "حکمدیا": "حکم دیا",
                               "حکمدے": "حکم دے",
                               "حکمپر": "حکم پر",
                               "حکمتعملی": "حکمت عملی",
                               "حکمرانوںنے": "حکمرانوں نے",
                               "حکومتاور": "حکومت اور",
                               "حکومتسے": "حکومت سے",
                               "حکومتپاکستان": "حکومت پاکستان",
                               "حکومتپر": "حکومت پر",
                               "حکومتپنجاب": "حکومت پنجاب",
                               "حکومتکا": "حکومت کا",
                               "حیدرآباد": "حیدر آباد",
                               "حیرانرہ": "حیران رہ",
                               "حیرانکر": "حیران کر",
                               "خاتونکا": "خاتون کا",
                               "خاتونکی": "خاتون کی",
                               "خاتونکے": "خاتون کے",
                               "خارجکر": "خارج کر",
                               "خارجہشاہ": "خارجہ شاہ",
                               "خارجہپالیسی": "خارجہ پالیسی",
                               "خاصطور": "خاص طور",
                               "خاقانعباسی": "خاقان عباسی",
                               "خاموشیسے": "خاموشی سے",
                               "خانکو": "خان کو",
                               "خانکی": "خان کی",
                               "خانکے": "خان کے",
                               "خاندانکی": "خاندان کی",
                               "خانہجنگی": "خانہ جنگی",
                               "خانےمیں": "خانے میں",
                               "خبردارکیا": "خبردار کیا",
                               "ختمنبوت": "ختم نبوت",
                               "ختمنہیں": "ختم نہیں",
                               "ختمکر": "ختم کر",
                               "ختمکرنے": "ختم کرنے",
                               "ختمہو": "ختم ہو",
                               "خداکا": "خدا کا",
                               "خداکی": "خدا کی",
                               "خداکے": "خدا کے",
                               "خدشہہے": "خدشہ ہے",
                               "خدمتمیں": "خدمت میں",
                               "خرابہو": "خراب ہو",
                               "خراجتحسین": "خراج تحسین",
                               "خرچکر": "خرچ کر",
                               "خصوصیطور": "خصوصی طور",
                               "خطمیں": "خط میں",
                               "خطابکر": "خطاب کر",
                               "خطابکے": "خطاب کے",
                               "خطرہہے": "خطرہ ہے",
                               "خطرےسے": "خطرے سے",
                               "خطرےمیں": "خطرے میں",
                               "خطہمیں": "خطہ میں",
                               "خطےکے": "خطے کے",
                               "خلافمقدمہ": "خلاف مقدمہ",
                               "خلافورزی": "خلاف ورزی",
                               "خواتیناور": "خواتین اور",
                               "خواتینکو": "خواتین کو",
                               "خواتینکے": "خواتین کے",
                               "خواجہآصف": "خواجہ آصف",
                               "خواہشکا": "خواہش کا",
                               "خواہشہے": "خواہش ہے",
                               "خوداپنے": "خود اپنے",
                               "خودمختاری": "خود مختاری",
                               "خودکشی": "خود کشی",
                               "خودکو": "خود کو",
                               "خورشیدشاہ": "خورشید شاہ",
                               "خوشآئند": "خوش آئند",
                               "خوشقسمتی": "خوش قسمتی",
                               "خوشیکا": "خوشی کا",
                               "خوفسے": "خوف سے",
                               "خوفو": "خوف و",
                               "خونسے": "خون سے",
                               "خونکا": "خون کا",
                               "خیالتھا": "خیال تھا",
                               "خیبرپختونخوا": "خیبر پختونخوا",
                               "خیبرپختونخواہ": "خیبر پختونخواہ",
                               "خیزمواد": "خیز مواد",
                               "دئیےگئے": "دئیے گئے",
                               "دائرکر": "دائر کر",
                               "دائرکی": "دائر کی",
                               "داخلہرحمان": "داخلہ رحمان",
                               "داخلہنے": "داخلہ نے",
                               "داخلہکے": "داخلہ کے",
                               "داعشکے": "داعش کے",
                               "دبئیمیں": "دبئی میں",
                               "درخواستدائر": "درخواست دائر",
                               "درخواستمیں": "درخواست میں",
                               "درخواستگزار": "درخواست گزار",
                               "درستنہیں": "درست نہیں",
                               "درستہے": "درست ہے",
                               "دریافتکیا": "دریافت کیا",
                               "دسسال": "دس سال",
                               "دسمبرء": "دسمبر ء",
                               "دسمبرمیں": "دسمبر میں",
                               "دسمبرکو": "دسمبر کو",
                               "دشمنکے": "دشمن کے",
                               "دعوتدی": "دعوت دی",
                               "دعویکیا": "دعوی کیا",
                               "دعویہے": "دعوی ہے",
                               "دفاعکے": "دفاع کے",
                               "دفترخارجہ": "دفتر خارجہ",
                               "دفترمیں": "دفتر میں",
                               "دلمیں": "دل میں",
                               "دلو": "دل و",
                               "دلکا": "دل کا",
                               "دلکو": "دل کو",
                               "دلکی": "دل کی",
                               "دلوںمیں": "دلوں میں",
                               "دلچسپبات": "دلچسپ بات",
                               "دمتوڑ": "دم توڑ",
                               "دماغمیں": "دماغ میں",
                               "دماغکو": "دماغ کو",
                               "دنبعد": "دن بعد",
                               "دنبھر": "دن بھر",
                               "دنتک": "دن تک",
                               "دنرات": "دن رات",
                               "دنسے": "دن سے",
                               "دنکی": "دن کی",
                               "دنوںمیں": "دنوں میں",
                               "دنیابھر": "دنیا بھر",
                               "دنیاکو": "دنیا کو",
                               "دنیاکی": "دنیا کی",
                               "دوافراد": "دو افراد",
                               "دوتین": "دو تین",
                               "دودن": "دو دن",
                               "دوروز": "دو روز",
                               "دوسو": "دو سو",
                               "دوماہ": "دو ماہ",
                               "دوچار": "دو چار",
                               "دوہزار": "دو ہزار",
                               "دورتک": "دور تک",
                               "دورحکومت": "دور حکومت",
                               "دورسے": "دور سے",
                               "دورمیں": "دور میں",
                               "دورکرنے": "دور کرنے",
                               "دورکی": "دور کی",
                               "دورکے": "دور کے",
                               "دورہو": "دور ہو",
                               "دورانایک": "دوران ایک",
                               "دورہکیا": "دورہ کیا",
                               "دورےپر": "دورے پر",
                               "دورےکے": "دورے کے",
                               "دوستوںکے": "دوستوں کے",
                               "دوسروںکو": "دوسروں کو",
                               "دوسروںکی": "دوسروں کی",
                               "دوسروںکے": "دوسروں کے",
                               "دوسریطرف": "دوسری طرف",
                               "دوسرےنمبر": "دوسرے نمبر",
                               "دوسرےکی": "دوسرے کی",
                               "دونوںممالک": "دونوں ممالک",
                               "دونوںنے": "دونوں نے",
                               "دونوںکو": "دونوں کو",
                               "دونوںکی": "دونوں کی",
                               "دوںگا": "دوں گا",
                               "دکھائیدے": "دکھائی دے",
                               "دھماکوںکے": "دھماکوں کے",
                               "دھماکےسے": "دھماکے سے",
                               "دھماکےمیں": "دھماکے میں",
                               "دھماکےکی": "دھماکے کی",
                               "دھمکیدی": "دھمکی دی",
                               "دہائیمیں": "دہائی میں",
                               "دہانیکرائی": "دہانی کرائی",
                               "دہشتگرد": "دہشت گرد",
                               "دہشتگردوں": "دہشت گردوں",
                               "دہلیمیں": "دہلی میں",
                               "دیتھی": "دی تھی",
                               "دیگئیں": "دی گئیں",
                               "دیئےجائیں": "دیئے جائیں",
                               "دیااور": "دیا اور",
                               "دیاتو": "دیا تو",
                               "دیاجاتا": "دیا جاتا",
                               "دیاجب": "دیا جب",
                               "دیاکہ": "دیا کہ",
                               "دیتاہوں": "دیتا ہوں",
                               "دیتیہے": "دیتی ہے",
                               "دیربعد": "دیر بعد",
                               "دیناچاہئے": "دینا چاہئے",
                               "دیناچاہیے": "دینا چاہیے",
                               "دینےمیں": "دینے میں",
                               "دینےوالی": "دینے والی",
                               "دینےکا": "دینے کا",
                               "دینےکی": "دینے کی",
                               "دینےکیلئے": "دینے کیلئے",
                               "دینےکے": "دینے کے",
                               "دیکھبھال": "دیکھ بھال",
                               "دیکھرہا": "دیکھ رہا",
                               "دیکھرہے": "دیکھ رہے",
                               "دیکھاتو": "دیکھا تو",
                               "دیکھاجا": "دیکھا جا",
                               "دیکھاکہ": "دیکھا کہ",
                               "دیکھاگیا": "دیکھا گیا",
                               "دیکھاہے": "دیکھا ہے",
                               "دیکھتےہوئے": "دیکھتے ہوئے",
                               "دیکھتےہی": "دیکھتے ہی",
                               "دیکھنےکو": "دیکھنے کو",
                               "دیکھنےکے": "دیکھنے کے",
                               "دیگرافراد": "دیگر افراد",
                               "دیگرممالک": "دیگر ممالک",
                               "دیںتو": "دیں تو",
                               "دیںگے": "دیں گے",
                               "دیےگئے": "دیے گئے",
                               "دےتو": "دے تو",
                               "دےدی": "دے دی",
                               "دےدیا": "دے دیا",
                               "دےرہے": "دے رہے",
                               "دےسکتا": "دے سکتا",
                               "دےسکتے": "دے سکتے",
                               "دےچکے": "دے چکے",
                               "دےکر": "دے کر",
                               "ذرائعکے": "ذرائع کے",
                               "ذمہدار": "ذمہ دار",
                               "ذمہداری": "ذمہ داری",
                               "ذمہداریاں": "ذمہ داریاں",
                               "ذکرکیا": "ذکر کیا",
                               "ذکرہے": "ذکر ہے",
                               "رابطہکر": "رابطہ کر",
                               "رابطےمیں": "رابطے میں",
                               "رابطےکی": "رابطے کی",
                               "راتگئے": "رات گئے",
                               "راستےمیں": "راستے میں",
                               "راولپنڈیمیں": "راولپنڈی میں",
                               "راہپر": "راہ پر",
                               "راہہموار": "راہ ہموار",
                               "رحمنملک": "رحمن ملک",
                               "رساںادارے": "رساں ادارے",
                               "رسولاللہ": "رسول اللہ",
                               "رشیدنے": "رشید نے",
                               "رضاگیلانی": "رضا گیلانی",
                               "رفتارسے": "رفتار سے",
                               "رمضانالمبارک": "رمضان المبارک",
                               "رنزبنائے": "رنز بنائے",
                               "رنزکی": "رنز کی",
                               "رواںبرس": "رواں برس",
                               "روزبھی": "روز بھی",
                               "روزتک": "روز تک",
                               "روزمیں": "روز میں",
                               "روزکے": "روز کے",
                               "روسکے": "روس کے",
                               "روشنیمیں": "روشنی میں",
                               "روممیں": "روم میں",
                               "روپےفی": "روپے فی",
                               "روپےمیں": "روپے میں",
                               "روپےپیسے": "روپے پیسے",
                               "روپےکی": "روپے کی",
                               "روکتھام": "روک تھام",
                               "روکدیا": "روک دیا",
                               "روکنےکی": "روکنے کی",
                               "روکنےکے": "روکنے کے",
                               "رپورٹمیں": "رپورٹ میں",
                               "رکنقومی": "رکن قومی",
                               "رکھدیں": "رکھ دیں",
                               "رکھکر": "رکھ کر",
                               "رکھاتھا": "رکھا تھا",
                               "رکھاجا": "رکھا جا",
                               "رکھاہے": "رکھا ہے",
                               "رکھتاہے": "رکھتا ہے",
                               "رکھتیہیں": "رکھتی ہیں",
                               "رکھتےتھے": "رکھتے تھے",
                               "رکھتےہیں": "رکھتے ہیں",
                               "رکھنےمیں": "رکھنے میں",
                               "رکھنےوالے": "رکھنے والے",
                               "رکھنےکیلئے": "رکھنے کیلئے",
                               "رکھیتھی": "رکھی تھی",
                               "رکھیگئی": "رکھی گئی",
                               "رکھیںگے": "رکھیں گے",
                               "رکھےہوئے": "رکھے ہوئے",
                               "رکھےہیں": "رکھے ہیں",
                               "رہجا": "رہ جا",
                               "رہکر": "رہ کر",
                               "رہاہوں": "رہا ہوں",
                               "رہائشگاہ": "رہائش گاہ",
                               "رہائیکے": "رہائی کے",
                               "رہتاہے": "رہتا ہے",
                               "رہتےہوئے": "رہتے ہوئے",
                               "رہتےہیں": "رہتے ہیں",
                               "رہنماؤںنے": "رہنماؤں نے",
                               "رہنےکا": "رہنے کا",
                               "رہیاور": "رہی اور",
                               "رہیتھی": "رہی تھی",
                               "رہیہو": "رہی ہو",
                               "رہیہوں": "رہی ہوں",
                               "رہیںاور": "رہیں اور",
                               "رہیںگے": "رہیں گے",
                               "رہےتو": "رہے تو",
                               "رہےگا": "رہے گا",
                               "رہےگی": "رہے گی",
                               "رہےہو": "رہے ہو",
                               "رہےہوتے": "رہے ہوتے",
                               "رہےہوں": "رہے ہوں",
                               "رہےہیں": "رہے ہیں",
                               "ریاستکے": "ریاست کے",
                               "ریمنڈڈیوس": "ریمنڈ ڈیوس",
                               "ریکارڈکی": "ریکارڈ کی",
                               "ریکارڈکیا": "ریکارڈ کیا",
                               "زائدافراد": "زائد افراد",
                               "زبانسے": "زبان سے",
                               "زبانکے": "زبان کے",
                               "زخمیہو": "زخمی ہو",
                               "زخمیوںکو": "زخمیوں کو",
                               "زرداریاور": "زرداری اور",
                               "زردارینے": "زرداری نے",
                               "زرداریکو": "زرداری کو",
                               "زلزلےکے": "زلزلے کے",
                               "زمینسے": "زمین سے",
                               "زندگیسے": "زندگی سے",
                               "زندگیمیں": "زندگی میں",
                               "زندگیکو": "زندگی کو",
                               "زندگیکے": "زندگی کے",
                               "زندگیگزارنے": "زندگی گزارنے",
                               "زورسے": "زور سے",
                               "زیادتیکا": "زیادتی کا",
                               "زیادہاستعمال": "زیادہ استعمال",
                               "زیادہبہتر": "زیادہ بہتر",
                               "زیادہتر": "زیادہ تر",
                               "زیادہدیر": "زیادہ دیر",
                               "زیادہہو": "زیادہ ہو",
                               "زیادہہوتا": "زیادہ ہوتا",
                               "زیرصدارت": "زیر صدارت",
                               "سائنسدانوں": "سائنس دانوں",
                               "سائنسدانوںکا": "سائنسدانوں کا",
                               "سابقصدر": "سابق صدر",
                               "سابقوزیر": "سابق وزیر",
                               "سابقکپتان": "سابق کپتان",
                               "ساتھان": "ساتھ ان",
                               "ساتھبھی": "ساتھ بھی",
                               "ساتھلے": "ساتھ لے",
                               "ساتھمذاکرات": "ساتھ مذاکرات",
                               "ساتھکام": "ساتھ کام",
                               "ساتھہی": "ساتھ ہی",
                               "ساتھہے": "ساتھ ہے",
                               "ساتھیہ": "ساتھ یہ",
                               "سافٹویئر": "سافٹ ویئر",
                               "سالء": "سال ء",
                               "سالتک": "سال تک",
                               "سالسے": "سال سے",
                               "سالقید": "سال قید",
                               "سالمیں": "سال میں",
                               "سالکا": "سال کا",
                               "سالکی": "سال کی",
                               "سالکے": "سال کے",
                               "سالوںسے": "سالوں سے",
                               "سامسنگ": "سام سنگ",
                               "سامناکرنا": "سامنا کرنا",
                               "سامنےآ": "سامنے آ",
                               "سامنےآئی": "سامنے آئی",
                               "سامنےآئے": "سامنے آئے",
                               "سامنےنہیں": "سامنے نہیں",
                               "سامنےپیش": "سامنے پیش",
                               "سبکا": "سب کا",
                               "سبکو": "سب کو",
                               "سبکچھ": "سب کچھ",
                               "سبکی": "سب کی",
                               "ستمبرکو": "ستمبر کو",
                               "سختیسے": "سختی سے",
                               "سرپرستی": "سر پرستی",
                               "سرحدپر": "سرحد پر",
                               "سرزمینپر": "سرزمین پر",
                               "سرفرازاحمد": "سرفراز احمد",
                               "سرمایہکاری": "سرمایہ کاری",
                               "سرچآپریشن": "سرچ آپریشن",
                               "سرکاریملازمین": "سرکاری ملازمین",
                               "سریلنکا": "سری لنکا",
                               "سریلنکن": "سری لنکن",
                               "سرےسے": "سرے سے",
                               "سزادی": "سزا دی",
                               "سزاسنائی": "سزا سنائی",
                               "سطحپر": "سطح پر",
                               "سعدرفیق": "سعد رفیق",
                               "سفارتخانے": "سفارت خانے",
                               "سفرکر": "سفر کر",
                               "سلامتیکے": "سلامتی کے",
                               "سلسلہشروع": "سلسلہ شروع",
                               "سلسلےمیں": "سلسلے میں",
                               "سلمانتاثیر": "سلمان تاثیر",
                               "سماجیرابطے": "سماجی رابطے",
                               "سمارٹفون": "سمارٹ فون",
                               "سماعتکی": "سماعت کی",
                               "سمجھمیں": "سمجھ میں",
                               "سمجھنہیں": "سمجھ نہیں",
                               "سمجھتاہوں": "سمجھتا ہوں",
                               "سمجھتاہے": "سمجھتا ہے",
                               "سمجھتےہیں": "سمجھتے ہیں",
                               "سمندرمیں": "سمندر میں",
                               "سمیتافراد": "سمیت افراد",
                               "سمیتتمام": "سمیت تمام",
                               "سمیتکئی": "سمیت کئی",
                               "سناہے": "سنا ہے",
                               "سنجیدگیسے": "سنجیدگی سے",
                               "سندھاور": "سندھ اور",
                               "سنگھنے": "سنگھ نے",
                               "سوسے": "سو سے",
                               "سواکچھ": "سوا کچھ",
                               "سواتمیں": "سوات میں",
                               "سوالپر": "سوال پر",
                               "سوالکا": "سوال کا",
                               "سورجکی": "سورج کی",
                               "سوشلمیڈیا": "سوشل میڈیا",
                               "سولسوسائٹی": "سول سوسائٹی",
                               "سونےسے": "سونے سے",
                               "سونےکی": "سونے کی",
                               "سونےکے": "سونے کے",
                               "سپرلیگ": "سپر لیگ",
                               "سچہے": "سچ ہے",
                               "سڑکپر": "سڑک پر",
                               "سکتاہوں": "سکتا ہوں",
                               "سکتاہے": "سکتا ہے",
                               "سکتیتھی": "سکتی تھی",
                               "سکتےتھے": "سکتے تھے",
                               "سکولمیں": "سکول میں",
                               "سکیورٹیفورسز": "سکیورٹی فورسز",
                               "سکیںگے": "سکیں گے",
                               "سکےاور": "سکے اور",
                               "سکےگی": "سکے گی",
                               "سیاو": "سی او",
                               "سیایل": "سی ایل",
                               "سیاین": "سی این",
                               "سیبی": "سی بی",
                               "سیسی": "سی سی",
                               "سینے": "سی نے",
                               "سیٹی": "سی ٹی",
                               "سیپی": "سی پی",
                               "سیپیک": "سی پیک",
                               "سیکیورٹی": "سی کیورٹی",
                               "سیاستدان": "سیاست دان",
                               "سیاستدانوں": "سیاست دانوں",
                               "سیاستکا": "سیاست کا",
                               "سیاستکے": "سیاست کے",
                               "سیاسیاور": "سیاسی اور",
                               "سیاسیجماعت": "سیاسی جماعت",
                               "سیاسیجماعتیں": "سیاسی جماعتیں",
                               "سیاسیقیادت": "سیاسی قیادت",
                               "سیاسیو": "سیاسی و",
                               "سیریزکے": "سیریز کے",
                               "سیلابزدگان": "سیلاب زدگان",
                               "سیلابسے": "سیلاب سے",
                               "سیمیفائنل": "سیمی فائنل",
                               "سینٹیگریڈ": "سینٹی گریڈ",
                               "سینےمیں": "سینے میں",
                               "سیکرٹریجنرل": "سیکرٹری جنرل",
                               "سےآج": "سے آج",
                               "سےآزاد": "سے آزاد",
                               "سےآنے": "سے آنے",
                               "سےآپ": "سے آپ",
                               "سےآگے": "سے آگے",
                               "سےاستعفی": "سے استعفی",
                               "سےافراد": "سے افراد",
                               "سےامریکہ": "سے امریکہ",
                               "سےامریکی": "سے امریکی",
                               "سےاور": "سے اور",
                               "سےاپنا": "سے اپنا",
                               "سےاپنی": "سے اپنی",
                               "سےاپنے": "سے اپنے",
                               "سےاپیل": "سے اپیل",
                               "سےبات": "سے بات",
                               "سےباز": "سے باز",
                               "سےباہر": "سے باہر",
                               "سےبتایا": "سے بتایا",
                               "سےبجلی": "سے بجلی",
                               "سےبچ": "سے بچ",
                               "سےبچا": "سے بچا",
                               "سےبچانے": "سے بچانے",
                               "سےبڑا": "سے بڑا",
                               "سےبڑی": "سے بڑی",
                               "سےبھارت": "سے بھارت",
                               "سےبھر": "سے بھر",
                               "سےبھری": "سے بھری",
                               "سےبہت": "سے بہت",
                               "سےتعلق": "سے تعلق",
                               "سےتعلقات": "سے تعلقات",
                               "سےتقریبا": "سے تقریبا",
                               "سےتنگ": "سے تنگ",
                               "سےتھا": "سے تھا",
                               "سےجاری": "سے جاری",
                               "سےجب": "سے جب",
                               "سےجسم": "سے جسم",
                               "سےجلد": "سے جلد",
                               "سےحکومت": "سے حکومت",
                               "سےخطاب": "سے خطاب",
                               "سےخود": "سے خود",
                               "سےخون": "سے خون",
                               "سےدرخواست": "سے درخواست",
                               "سےدنیا": "سے دنیا",
                               "سےدور": "سے دور",
                               "سےدہشت": "سے دہشت",
                               "سےدیکھا": "سے دیکھا",
                               "سےرابطے": "سے رابطے",
                               "سےرجوع": "سے رجوع",
                               "سےروک": "سے روک",
                               "سےروکنے": "سے روکنے",
                               "سےسال": "سے سال",
                               "سےسب": "سے سب",
                               "سےسخت": "سے سخت",
                               "سےسوال": "سے سوال",
                               "سےشدید": "سے شدید",
                               "سےشکست": "سے شکست",
                               "سےصاف": "سے صاف",
                               "سےظاہر": "سے ظاہر",
                               "سےعلیحدگی": "سے علیحدگی",
                               "سےغیر": "سے غیر",
                               "سےفارغ": "سے فارغ",
                               "سےفرار": "سے فرار",
                               "سےفی": "سے فی",
                               "سےقاصر": "سے قاصر",
                               "سےلطف": "سے لطف",
                               "سےلیس": "سے لیس",
                               "سےلے": "سے لے",
                               "سےمتاثرہ": "سے متاثرہ",
                               "سےمحروم": "سے محروم",
                               "سےمذاکرات": "سے مذاکرات",
                               "سےمزید": "سے مزید",
                               "سےمطالبہ": "سے مطالبہ",
                               "سےمعافی": "سے معافی",
                               "سےمعلوم": "سے معلوم",
                               "سےمل": "سے مل",
                               "سےملاقات": "سے ملاقات",
                               "سےمنسلک": "سے منسلک",
                               "سےمکمل": "سے مکمل",
                               "سےنجات": "سے نجات",
                               "سےنوازا": "سے نوازا",
                               "سےنکالنے": "سے نکالنے",
                               "سےنکلنے": "سے نکلنے",
                               "سےنہ": "سے نہ",
                               "سےنہیں": "سے نہیں",
                               "سےنیچے": "سے نیچے",
                               "سےواقف": "سے واقف",
                               "سےواپس": "سے واپس",
                               "سےوہ": "سے وہ",
                               "سےپانچ": "سے پانچ",
                               "سےپاکستان": "سے پاکستان",
                               "سےپاکستانی": "سے پاکستانی",
                               "سےپر": "سے پر",
                               "سےپیدا": "سے پیدا",
                               "سےپیش": "سے پیش",
                               "سےچار": "سے چار",
                               "سےچند": "سے چند",
                               "سےکافی": "سے کافی",
                               "سےکام": "سے کام",
                               "سےکر": "سے کر",
                               "سےکسی": "سے کسی",
                               "سےکم": "سے کم",
                               "سےکو": "سے کو",
                               "سےکچھ": "سے کچھ",
                               "سےکہا": "سے کہا",
                               "سےکہہ": "سے کہہ",
                               "سےکیا": "سے کیا",
                               "سےگرفتار": "سے گرفتار",
                               "سےگزر": "سے گزر",
                               "سےگفتگو": "سے گفتگو",
                               "سےہاتھ": "سے ہاتھ",
                               "سےہزار": "سے ہزار",
                               "سےہمارے": "سے ہمارے",
                               "سےہوئی": "سے ہوئی",
                               "سےہوا": "سے ہوا",
                               "سےہٹ": "سے ہٹ",
                               "سےہی": "سے ہی",
                               "سےہیں": "سے ہیں",
                               "سےہے": "سے ہے",
                               "شائعہو": "شائع ہو",
                               "شادیسے": "شادی سے",
                               "شادیشدہ": "شادی شدہ",
                               "شادیکا": "شادی کا",
                               "شادیکر": "شادی کر",
                               "شادیکرنے": "شادی کرنے",
                               "شادیکی": "شادی کی",
                               "شادیکے": "شادی کے",
                               "شاممیں": "شام میں",
                               "شامکے": "شام کے",
                               "شاملنہیں": "شامل نہیں",
                               "شاملکرنے": "شامل کرنے",
                               "شاملہے": "شامل ہے",
                               "شاہدخاقان": "شاہد خاقان",
                               "شایداس": "شاید اس",
                               "شجاعتحسین": "شجاعت حسین",
                               "شخصکو": "شخص کو",
                               "شخصیتکے": "شخصیت کے",
                               "شدتسے": "شدت سے",
                               "شدیدتنقید": "شدید تنقید",
                               "شدیدزخمی": "شدید زخمی",
                               "شروعکرنے": "شروع کرنے",
                               "شروعہو": "شروع ہو",
                               "شروعہوئی": "شروع ہوئی",
                               "شروعہوا": "شروع ہوا",
                               "شرکتکی": "شرکت کی",
                               "شرکتکے": "شرکت کے",
                               "شریفبرادران": "شریف برادران",
                               "شریفخاندان": "شریف خاندان",
                               "شریفکو": "شریف کو",
                               "شریفکی": "شریف کی",
                               "شریفکے": "شریف کے",
                               "شعبوںمیں": "شعبوں میں",
                               "شمولیتکا": "شمولیت کا",
                               "شناختیکارڈ": "شناختی کارڈ",
                               "شومیں": "شو میں",
                               "شوکتعزیز": "شوکت عزیز",
                               "شکنہیں": "شک نہیں",
                               "شکارہے": "شکار ہے",
                               "شکریہادا": "شکریہ ادا",
                               "شکستدے": "شکست دے",
                               "شکلمیں": "شکل میں",
                               "شہبازشریف": "شہباز شریف",
                               "شہرمیں": "شہر میں",
                               "شہرکی": "شہر کی",
                               "شہریوںکے": "شہریوں کے",
                               "شہیدہو": "شہید ہو",
                               "شیئرکی": "شیئر کی",
                               "صاحبسے": "صاحب سے",
                               "صاحبنے": "صاحب نے",
                               "صاحبکا": "صاحب کا",
                               "صارفینکی": "صارفین کی",
                               "صارفینکے": "صارفین کے",
                               "صافکر": "صاف کر",
                               "صحافیوںسے": "صحافیوں سے",
                               "صحتکا": "صحت کا",
                               "صحتکے": "صحت کے",
                               "صداضافہ": "صد اضافہ",
                               "صدتک": "صد تک",
                               "صدسے": "صد سے",
                               "صدرآصف": "صدر آصف",
                               "صدراوباما": "صدر اوباما",
                               "صدرزرداری": "صدر زرداری",
                               "صدرصاحب": "صدر صاحب",
                               "صدرمشرف": "صدر مشرف",
                               "صدرپاکستان": "صدر پاکستان",
                               "صدرپرویز": "صدر پرویز",
                               "صدرکا": "صدر کا",
                               "صدرکو": "صدر کو",
                               "صرفاور": "صرف اور",
                               "صرفاپنے": "صرف اپنے",
                               "صرفایک": "صرف ایک",
                               "صرفپاکستان": "صرف پاکستان",
                               "صرفیہ": "صرف یہ",
                               "صوبائیاسمبلی": "صوبائی اسمبلی",
                               "صوبائیحکومت": "صوبائی حکومت",
                               "صوبائیوزیر": "صوبائی وزیر",
                               "صوبوںمیں": "صوبوں میں",
                               "صوبوںکے": "صوبوں کے",
                               "صوبےمیں": "صوبے میں",
                               "صوبےکے": "صوبے کے",
                               "صورتحال": "صورت حال",
                               "ضرورتاس": "ضرورت اس",
                               "ضرورتنہیں": "ضرورت نہیں",
                               "ضرورتہوتی": "ضرورت ہوتی",
                               "ضرورتہے": "ضرورت ہے",
                               "ضرورینہیں": "ضروری نہیں",
                               "ضروریہے": "ضروری ہے",
                               "ضیاءالحق": "ضیاء الحق",
                               "طاقتکا": "طاقت کا",
                               "طاقتکے": "طاقت کے",
                               "طالبعلموں": "طالب علموں",
                               "طالبانسے": "طالبان سے",
                               "طالباننے": "طالبان نے",
                               "طالبانکو": "طالبان کو",
                               "طالبانکی": "طالبان کی",
                               "طبیامداد": "طبی امداد",
                               "طبیماہرین": "طبی ماہرین",
                               "طرحاس": "طرح اس",
                               "طرحسے": "طرح سے",
                               "طرحطرح": "طرح طرح",
                               "طرحکا": "طرح کا",
                               "طرحکی": "طرح کی",
                               "طرحکے": "طرح کے",
                               "طرزعمل": "طرز عمل",
                               "طریقےسے": "طریقے سے",
                               "طلبکیا": "طلب کیا",
                               "طویلعرصے": "طویل عرصے",
                               "طیاروںکی": "طیاروں کی",
                               "طیارےمیں": "طیارے میں",
                               "طیارےکے": "طیارے کے",
                               "طےشدہ": "طے شدہ",
                               "طےکر": "طے کر",
                               "ظاہرکر": "ظاہر کر",
                               "ظاہرکی": "ظاہر کی",
                               "ظاہرہے": "ظاہر ہے",
                               "ظلمو": "ظلم و",
                               "عائدکی": "عائد کی",
                               "عائشہگلالئی": "عائشہ گلالئی",
                               "عالماسلام": "عالم اسلام",
                               "عالممیں": "عالم میں",
                               "عالمیسطح": "عالمی سطح",
                               "عامآدمی": "عام آدمی",
                               "عباسینے": "عباسی نے",
                               "عجیبو": "عجیب و",
                               "عدالتعظمی": "عدالت عظمی",
                               "عدالتمیں": "عدالت میں",
                               "عدالتنے": "عدالت نے",
                               "عدالتکی": "عدالت کی",
                               "عدالتوںمیں": "عدالتوں میں",
                               "عدلیہکو": "عدلیہ کو",
                               "عدماستحکام": "عدم استحکام",
                               "عراقاور": "عراق اور",
                               "عراقکے": "عراق کے",
                               "عربممالک": "عرب ممالک",
                               "عرصےتک": "عرصے تک",
                               "عرصےمیں": "عرصے میں",
                               "عروجپر": "عروج پر",
                               "عزتو": "عزت و",
                               "عسکریتپسندوں": "عسکریت پسندوں",
                               "علاجکے": "علاج کے",
                               "علاقوںسے": "علاقوں سے",
                               "علاقےمیں": "علاقے میں",
                               "علاقےکو": "علاقے کو",
                               "علاقےکے": "علاقے کے",
                               "علاوہازیں": "علاوہ ازیں",
                               "علمنہیں": "علم نہیں",
                               "علیجناح": "علی جناح",
                               "علیخان": "علی خان",
                               "علیزرداری": "علی زرداری",
                               "علیکرم": "علی کرم",
                               "علیکی": "علی کی",
                               "علیکے": "علی کے",
                               "علیہالسلام": "علیہ السلام",
                               "علیہوسلم": "علیہ وسلم",
                               "عمراکمل": "عمر اکمل",
                               "عملدرآمد": "عمل درآمد",
                               "عملمیں": "عمل میں",
                               "عملپیرا": "عمل پیرا",
                               "عملکا": "عمل کا",
                               "عملکر": "عمل کر",
                               "عملکی": "عمل کی",
                               "عملکے": "عمل کے",
                               "عملہے": "عمل ہے",
                               "عواماور": "عوام اور",
                               "عوامپر": "عوام پر",
                               "عوامیتحریک": "عوامی تحریک",
                               "عورتکو": "عورت کو",
                               "عہدےسے": "عہدے سے",
                               "عہدےپر": "عہدے پر",
                               "غائبہو": "غائب ہو",
                               "غرضسے": "غرض سے",
                               "غریبعوام": "غریب عوام",
                               "غلطہے": "غلط ہے",
                               "غورکیا": "غور کیا",
                               "غیرضروری": "غیر ضروری",
                               "غیرملکی": "غیر ملکی",
                               "غیرملکیوں": "غیر ملکیوں",
                               "فاروقستار": "فاروق ستار",
                               "فاصلےپر": "فاصلے پر",
                               "فرارہو": "فرار ہو",
                               "فرانسکے": "فرانس کے",
                               "فراہمکرتا": "فراہم کرتا",
                               "فراہمکرنے": "فراہم کرنے",
                               "فراہمکرے": "فراہم کرے",
                               "فراہمکیا": "فراہم کیا",
                               "فردجرم": "فرد جرم",
                               "فرضہے": "فرض ہے",
                               "فرقنہیں": "فرق نہیں",
                               "فرماتےہیں": "فرماتے ہیں",
                               "فرمایاکہ": "فرمایا کہ",
                               "فروختکر": "فروخت کر",
                               "فروختکرنے": "فروخت کرنے",
                               "فروریء": "فروری ء",
                               "فضامیں": "فضا میں",
                               "فضلالرحمان": "فضل الرحمان",
                               "فضلالرحمن": "فضل الرحمن",
                               "فلمانڈسٹری": "فلم انڈسٹری",
                               "فلممیں": "فلم میں",
                               "فلموںکی": "فلموں کی",
                               "فوجاور": "فوج اور",
                               "فوجکا": "فوج کا",
                               "فوجکی": "فوج کی",
                               "فوجکے": "فوج کے",
                               "فوجیآپریشن": "فوجی آپریشن",
                               "فوجیوںکی": "فوجیوں کی",
                               "فوریطور": "فوری طور",
                               "فونکی": "فون کی",
                               "فونکے": "فون کے",
                               "فیالحال": "فی الحال",
                               "فیصلشہزاد": "فیصل شہزاد",
                               "فیصلہکر": "فیصلہ کر",
                               "فیصلہکن": "فیصلہ کن",
                               "فیصلہکیا": "فیصلہ کیا",
                               "فیصلےسے": "فیصلے سے",
                               "فیصلےکو": "فیصلے کو",
                               "قلیگ": "ق لیگ",
                               "قائمکی": "قائم کی",
                               "قائمکیا": "قائم کیا",
                               "قائمہو": "قائم ہو",
                               "قائمہکمیٹی": "قائمہ کمیٹی",
                               "قابلقبول": "قابل قبول",
                               "قابوپانے": "قابو پانے",
                               "قانونسازی": "قانون سازی",
                               "قانوننافذ": "قانون نافذ",
                               "قانونکے": "قانون کے",
                               "قانونیطور": "قانونی طور",
                               "قبضہکر": "قبضہ کر",
                               "قبضےمیں": "قبضے میں",
                               "قبلاز": "قبل از",
                               "قبلازیں": "قبل ازیں",
                               "قبلبھی": "قبل بھی",
                               "قبلہی": "قبل ہی",
                               "قبولکر": "قبول کر",
                               "قبولکرنے": "قبول کرنے",
                               "قتلعام": "قتل عام",
                               "قتلکا": "قتل کا",
                               "قتلکرنے": "قتل کرنے",
                               "قتلکی": "قتل کی",
                               "قتلکیا": "قتل کیا",
                               "قتلکیس": "قتل کیس",
                               "قرآنپاک": "قرآن پاک",
                               "قرارداد": "قرار داد",
                               "قراردینے": "قرار دینے",
                               "قراردے": "قرار دے",
                               "قریشینے": "قریشی نے",
                               "قسمکی": "قسم کی",
                               "قسمکے": "قسم کے",
                               "قسمتیسے": "قسمتی سے",
                               "قندیلبلوچ": "قندیل بلوچ",
                               "قوانینکی": "قوانین کی",
                               "قوانینکے": "قوانین کے",
                               "قومسے": "قوم سے",
                               "قومکا": "قوم کا",
                               "قومکو": "قوم کو",
                               "قومکی": "قوم کی",
                               "قومکے": "قوم کے",
                               "قومیاسمبلی": "قومی اسمبلی",
                               "قومیسلامتی": "قومی سلامتی",
                               "قومیمفادات": "قومی مفادات",
                               "قومیموومنٹ": "قومی موومنٹ",
                               "قومیکرکٹ": "قومی کرکٹ",
                               "قیادتسے": "قیادت سے",
                               "قیادتنے": "قیادت نے",
                               "قیادتکو": "قیادت کو",
                               "قیادتکی": "قیادت کی",
                               "قیادتکے": "قیادت کے",
                               "قیامامن": "قیام امن",
                               "قیامپاکستان": "قیام پاکستان",
                               "قیامکے": "قیام کے",
                               "قیدکی": "قید کی",
                               "قیمتروپے": "قیمت روپے",
                               "قیمتپر": "قیمت پر",
                               "قیمتوںمیں": "قیمتوں میں",
                               "لئےاستعمال": "لئے استعمال",
                               "لئےان": "لئے ان",
                               "لئےبہت": "لئے بہت",
                               "لئےتیار": "لئے تیار",
                               "لئےوہ": "لئے وہ",
                               "لئےکو": "لئے کو",
                               "لاکر": "لا کر",
                               "لائحہعمل": "لائحہ عمل",
                               "لاحقہو": "لاحق ہو",
                               "لالمسجد": "لال مسجد",
                               "لانگمارچ": "لانگ مارچ",
                               "لانےکا": "لانے کا",
                               "لانےکی": "لانے کی",
                               "لانےکے": "لانے کے",
                               "لاکھروپے": "لاکھ روپے",
                               "لاکھسے": "لاکھ سے",
                               "لاکھڈالر": "لاکھ ڈالر",
                               "لاکھہزار": "لاکھ ہزار",
                               "لاہورمیں": "لاہور میں",
                               "لایاجا": "لایا جا",
                               "لایاگیا": "لایا گیا",
                               "لطفاندوز": "لطف اندوز",
                               "لندنکے": "لندن کے",
                               "لنکاکے": "لنکا کے",
                               "لوٹمار": "لوٹ مار",
                               "لوڈشیڈنگ": "لوڈ شیڈنگ",
                               "لوگان": "لوگ ان",
                               "لوگاپنے": "لوگ اپنے",
                               "لوگبھی": "لوگ بھی",
                               "لوگجو": "لوگ جو",
                               "لوگہیں": "لوگ ہیں",
                               "لوگربل": "لوگر بل",
                               "لوگوںنے": "لوگوں نے",
                               "لوگوںکی": "لوگوں کی",
                               "لوگوںکے": "لوگوں کے",
                               "لپیٹمیں": "لپیٹ میں",
                               "لڑکینے": "لڑکی نے",
                               "لڑکیکی": "لڑکی کی",
                               "لڑکیکے": "لڑکی کے",
                               "لڑکیوںکو": "لڑکیوں کو",
                               "لکھکر": "لکھ کر",
                               "لکھاتھا": "لکھا تھا",
                               "لکھاکہ": "لکھا کہ",
                               "لکھتےہیں": "لکھتے ہیں",
                               "لگگئی": "لگ گئی",
                               "لگادی": "لگا دی",
                               "لگادیا": "لگا دیا",
                               "لگاکر": "لگا کر",
                               "لگاکہ": "لگا کہ",
                               "لگاہے": "لگا ہے",
                               "لگائےگئے": "لگائے گئے",
                               "لگانےکا": "لگانے کا",
                               "لگانےکی": "لگانے کی",
                               "لگانےکے": "لگانے کے",
                               "لگایاجا": "لگایا جا",
                               "لگایاگیا": "لگایا گیا",
                               "لگتاہے": "لگتا ہے",
                               "لگیہے": "لگی ہے",
                               "لگےگا": "لگے گا",
                               "لگےہیں": "لگے ہیں",
                               "لہجےمیں": "لہجے میں",
                               "لہذااس": "لہذا اس",
                               "لیاور": "لی اور",
                               "لیتھی": "لی تھی",
                               "لیجا": "لی جا",
                               "لیاجا": "لیا جا",
                               "لیاجاتا": "لیا جاتا",
                               "لیبیاکے": "لیبیا کے",
                               "لیتیہے": "لیتی ہے",
                               "لیتےہیں": "لیتے ہیں",
                               "لیموںکا": "لیموں کا",
                               "لیناچاہئے": "لینا چاہئے",
                               "لینڈمیں": "لینڈ میں",
                               "لینڈکی": "لینڈ کی",
                               "لینےسے": "لینے سے",
                               "لینےوالے": "لینے والے",
                               "لیپٹاپ": "لیپ ٹاپ",
                               "لیکسکے": "لیکس کے",
                               "لیکنآج": "لیکن آج",
                               "لیکناب": "لیکن اب",
                               "لیکنان": "لیکن ان",
                               "لیکنایک": "لیکن ایک",
                               "لیکنمیں": "لیکن میں",
                               "لیکنپھر": "لیکن پھر",
                               "لیکنہم": "لیکن ہم",
                               "لیکنیہ": "لیکن یہ",
                               "لیگمیں": "لیگ میں",
                               "لیگکے": "لیگ کے",
                               "لیںتو": "لیں تو",
                               "لیںکہ": "لیں کہ",
                               "لیےاستعمال": "لیے استعمال",
                               "لیےان": "لیے ان",
                               "لیےبہت": "لیے بہت",
                               "لیےتیار": "لیے تیار",
                               "لیےضروری": "لیے ضروری",
                               "لیےپیش": "لیے پیش",
                               "لیےیہ": "لیے یہ",
                               "لےجا": "لے جا",
                               "لےجایا": "لے جایا",
                               "لےرہی": "لے رہی",
                               "لےرہے": "لے رہے",
                               "لےلی": "لے لی",
                               "لےلیا": "لے لیا",
                               "لےگئے": "لے گئے",
                               "لےگا": "لے گا",
                               "لےگی": "لے گی",
                               "لےگیا": "لے گیا",
                               "مئیکو": "مئی کو",
                               "ماحولمیں": "ماحول میں",
                               "مارشللاء": "مارشل لاء",
                               "مارچء": "مارچ ء",
                               "مارچمیں": "مارچ میں",
                               "ماضیکی": "ماضی کی",
                               "ماضیکے": "ماضی کے",
                               "ماںباپ": "ماں باپ",
                               "ماںکو": "ماں کو",
                               "ماںکی": "ماں کی",
                               "ماںکے": "ماں کے",
                               "ماہبعد": "ماہ بعد",
                               "ماہتک": "ماہ تک",
                               "ماہسے": "ماہ سے",
                               "ماہقبل": "ماہ قبل",
                               "ماہکی": "ماہ کی",
                               "ماہرہخان": "ماہرہ خان",
                               "ماہریننے": "ماہرین نے",
                               "ماہرینکا": "ماہرین کا",
                               "مبتلاہو": "مبتلا ہو",
                               "متاثرینکی": "متاثرین کی",
                               "متحدہو": "متحد ہو",
                               "متحدہقومی": "متحدہ قومی",
                               "مترادفہے": "مترادف ہے",
                               "متعارفکرایا": "متعارف کرایا",
                               "متوقعہے": "متوقع ہے",
                               "مثالکے": "مثال کے",
                               "مجبورکر": "مجبور کر",
                               "مجبورکیا": "مجبور کیا",
                               "مجبورہیں": "مجبور ہیں",
                               "مجھسے": "مجھ سے",
                               "مجھپر": "مجھ پر",
                               "مجھےاس": "مجھے اس",
                               "مجھےیہ": "مجھے یہ",
                               "محبوطن": "محب وطن",
                               "محبتکا": "محبت کا",
                               "محبتکی": "محبت کی",
                               "محترمہبے": "محترمہ بے",
                               "محرومہو": "محروم ہو",
                               "محسوسنہیں": "محسوس نہیں",
                               "محسوسکر": "محسوس کر",
                               "محسوسہو": "محسوس ہو",
                               "محسوسہوتا": "محسوس ہوتا",
                               "محفوظکر": "محفوظ کر",
                               "محمدبن": "محمد بن",
                               "محمدحفیظ": "محمد حفیظ",
                               "محمدعامر": "محمد عامر",
                               "محمدچودھری": "محمد چودھری",
                               "محمدچوہدری": "محمد چوہدری",
                               "مخالفتکی": "مخالفت کی",
                               "مدمیں": "مد میں",
                               "مددسے": "مدد سے",
                               "مددملے": "مدد ملے",
                               "مددکر": "مدد کر",
                               "مددکی": "مدد کی",
                               "مددکے": "مدد کے",
                               "مددگارثابت": "مددگار ثابت",
                               "مذاکراتمیں": "مذاکرات میں",
                               "مذاکراتکا": "مذاکرات کا",
                               "مذمتکر": "مذمت کر",
                               "مذمتکی": "مذمت کی",
                               "مذہبیامور": "مذہبی امور",
                               "مرتبہپھر": "مرتبہ پھر",
                               "مرحلےمیں": "مرحلے میں",
                               "مردوںکو": "مردوں کو",
                               "مردوںکی": "مردوں کی",
                               "مردوںکے": "مردوں کے",
                               "مرضیسے": "مرضی سے",
                               "مرضیکے": "مرضی کے",
                               "مرکزیکردار": "مرکزی کردار",
                               "مریضوںکو": "مریضوں کو",
                               "مریمنواز": "مریم نواز",
                               "مزیداضافہ": "مزید اضافہ",
                               "مزیدبتایا": "مزید بتایا",
                               "مزیدکہا": "مزید کہا",
                               "مسئلہحل": "مسئلہ حل",
                               "مسئلہکشمیر": "مسئلہ کشمیر",
                               "مسئلہہے": "مسئلہ ہے",
                               "مسئلےپر": "مسئلے پر",
                               "مسئلےکا": "مسئلے کا",
                               "مسئلےکو": "مسئلے کو",
                               "مسائلحل": "مسائل حل",
                               "مسائلسے": "مسائل سے",
                               "مسائلپر": "مسائل پر",
                               "مسائلکو": "مسائل کو",
                               "مسافروںکو": "مسافروں کو",
                               "مستعفیہو": "مستعفی ہو",
                               "مستقبلکی": "مستقبل کی",
                               "مستقبلکے": "مستقبل کے",
                               "مسجدمیں": "مسجد میں",
                               "مسجدکے": "مسجد کے",
                               "مسلحافواج": "مسلح افواج",
                               "مسلمامہ": "مسلم امہ",
                               "مسلمممالک": "مسلم ممالک",
                               "مسلمانوںکا": "مسلمانوں کا",
                               "مسلمانوںکی": "مسلمانوں کی",
                               "مسلمانوںکے": "مسلمانوں کے",
                               "مشتملہے": "مشتمل ہے",
                               "مشرفکا": "مشرف کا",
                               "مشرقیپاکستان": "مشرقی پاکستان",
                               "مشکلسے": "مشکل سے",
                               "مشکلہو": "مشکل ہو",
                               "مشکلہے": "مشکل ہے",
                               "مصباحالحق": "مصباح الحق",
                               "مصرمیں": "مصر میں",
                               "مصرکے": "مصر کے",
                               "مصروفہے": "مصروف ہے",
                               "مصنوعاتکی": "مصنوعات کی",
                               "مطابقان": "مطابق ان",
                               "مطابقوزیر": "مطابق وزیر",
                               "مطابقپاکستان": "مطابق پاکستان",
                               "مطالبہکر": "مطالبہ کر",
                               "مطالبہکیا": "مطالبہ کیا",
                               "مطلبہے": "مطلب ہے",
                               "مطلبیہ": "مطلب یہ",
                               "مظاہرہکر": "مظاہرہ کر",
                               "مظاہریننے": "مظاہرین نے",
                               "معاشرےکی": "معاشرے کی",
                               "معاشرےکے": "معاشرے کے",
                               "معافکر": "معاف کر",
                               "معاملاتپر": "معاملات پر",
                               "معاملاتکو": "معاملات کو",
                               "معاملہمیں": "معاملہ میں",
                               "معاملہہے": "معاملہ ہے",
                               "معاملےکو": "معاملے کو",
                               "معاملےکی": "معاملے کی",
                               "معاہدےپر": "معاہدے پر",
                               "معاہدےکی": "معاہدے کی",
                               "معاہدےکے": "معاہدے کے",
                               "معطلکر": "معطل کر",
                               "معلومہو": "معلوم ہو",
                               "معلومہوا": "معلوم ہوا",
                               "معلومہوتا": "معلوم ہوتا",
                               "معنوںمیں": "معنوں میں",
                               "معیشتکو": "معیشت کو",
                               "مغربمیں": "مغرب میں",
                               "مغربکی": "مغرب کی",
                               "مغربیممالک": "مغربی ممالک",
                               "مفادمیں": "مفاد میں",
                               "مفاداتکی": "مفادات کی",
                               "مفیدہے": "مفید ہے",
                               "مقابلہکرنے": "مقابلہ کرنے",
                               "مقابلےمیں": "مقابلے میں",
                               "مقاصدکے": "مقاصد کے",
                               "مقاماتپر": "مقامات پر",
                               "مقبوضہکشمیر": "مقبوضہ کشمیر",
                               "مقدمےمیں": "مقدمے میں",
                               "مقدمےکی": "مقدمے کی",
                               "مقررکر": "مقرر کر",
                               "مقررکیا": "مقرر کیا",
                               "ملجا": "مل جا",
                               "ملسکے": "مل سکے",
                               "ملکر": "مل کر",
                               "ملگئی": "مل گئی",
                               "ملگیا": "مل گیا",
                               "ملاہے": "ملا ہے",
                               "ملازمینکو": "ملازمین کو",
                               "ملازمینکی": "ملازمین کی",
                               "ملاقاتکی": "ملاقات کی",
                               "ملاقاتہوئی": "ملاقات ہوئی",
                               "ملتےہیں": "ملتے ہیں",
                               "ملزمنے": "ملزم نے",
                               "ملزمکو": "ملزم کو",
                               "ملزمانکو": "ملزمان کو",
                               "ملنےوالی": "ملنے والی",
                               "ملنےوالے": "ملنے والے",
                               "ملنےپر": "ملنے پر",
                               "ملنےکے": "ملنے کے",
                               "ملوثہو": "ملوث ہو",
                               "ملوثہیں": "ملوث ہیں",
                               "ملکبھر": "ملک بھر",
                               "ملکسے": "ملک سے",
                               "ملکو": "ملک و",
                               "ملککا": "ملک کا",
                               "ملککو": "ملک کو",
                               "ملکوںمیں": "ملکوں میں",
                               "ملکوںکی": "ملکوں کی",
                               "ملکیخبر": "ملکی خبر",
                               "ملیہے": "ملی ہے",
                               "ملینڈالر": "ملین ڈالر",
                               "ممالکسے": "ممالک سے",
                               "ممالکمیں": "ممالک میں",
                               "ممالککو": "ممالک کو",
                               "ممالککے": "ممالک کے",
                               "ممبئیحملوں": "ممبئی حملوں",
                               "ممکنہو": "ممکن ہو",
                               "ممکنہے": "ممکن ہے",
                               "ممکنہطور": "ممکنہ طور",
                               "منموہن": "من موہن",
                               "منتخبہو": "منتخب ہو",
                               "منتقلکر": "منتقل کر",
                               "منتقلہو": "منتقل ہو",
                               "مندہے": "مند ہے",
                               "منسوخکر": "منسوخ کر",
                               "منصوبہبندی": "منصوبہ بندی",
                               "منصوبےپر": "منصوبے پر",
                               "منصوبےکی": "منصوبے کی",
                               "منصوبےکے": "منصوبے کے",
                               "منظرمیں": "منظر میں",
                               "منظورکر": "منظور کر",
                               "منظوریدی": "منظوری دی",
                               "منظوریکے": "منظوری کے",
                               "منعقدہو": "منعقد ہو",
                               "منفیاثرات": "منفی اثرات",
                               "منٹتک": "منٹ تک",
                               "منٹمیں": "منٹ میں",
                               "منگلکو": "منگل کو",
                               "منہسے": "منہ سے",
                               "منہمیں": "منہ میں",
                               "منیلانڈرنگ": "منی لانڈرنگ",
                               "موبائلفون": "موبائل فون",
                               "موتکا": "موت کا",
                               "موجودتھا": "موجود تھا",
                               "موجودہیں": "موجود ہیں",
                               "موجودہے": "موجود ہے",
                               "موجودہحالات": "موجودہ حالات",
                               "موسممیں": "موسم میں",
                               "موسمیاتکے": "موسمیات کے",
                               "موصولہو": "موصول ہو",
                               "موضوعپر": "موضوع پر",
                               "موقعفراہم": "موقع فراہم",
                               "موقعملا": "موقع ملا",
                               "موٹرسائیکل": "موٹر سائیکل",
                               "موہنسنگھ": "موہن سنگھ",
                               "مکملطور": "مکمل طور",
                               "مکملکر": "مکمل کر",
                               "مکملکرنے": "مکمل کرنے",
                               "مکملہو": "مکمل ہو",
                               "مگراس": "مگر اس",
                               "مگرجب": "مگر جب",
                               "مگرپھر": "مگر پھر",
                               "مگرہم": "مگر ہم",
                               "مہمان": "مہم ان",
                               "مہمانوں": "مہم انوں",
                               "مہمکے": "مہم کے",
                               "مہنگائیکے": "مہنگائی کے",
                               "مہینہ": "مہی نہ",
                               "مہینےمیں": "مہینے میں",
                               "میاںبیوی": "میاں بیوی",
                               "میاںعبدالرشید": "میاں عبدالرشید",
                               "میاںمحمد": "میاں محمد",
                               "میاںنواز": "میاں نواز",
                               "میثاقجمہوریت": "میثاق جمہوریت",
                               "میجرجنرل": "میجر جنرل",
                               "میدانمیں": "میدان میں",
                               "میرےخیال": "میرے خیال",
                               "میرےساتھ": "میرے ساتھ",
                               "میرےلئے": "میرے لئے",
                               "میزپر": "میز پر",
                               "میچمیں": "میچ میں",
                               "میچکے": "میچ کے",
                               "میچزمیں": "میچز میں",
                               "میچوںمیں": "میچوں میں",
                               "میڈیارپورٹس": "میڈیا رپورٹس",
                               "میڈیاسے": "میڈیا سے",
                               "میڈیامیں": "میڈیا میں",
                               "میڈیانے": "میڈیا نے",
                               "میڈیاپر": "میڈیا پر",
                               "میڈیاکے": "میڈیا کے",
                               "میکاپ": "میک اپ",
                               "میںآنے": "میں آنے",
                               "میںآپ": "میں آپ",
                               "میںآگ": "میں آگ",
                               "میںابھی": "میں ابھی",
                               "میںاتنی": "میں اتنی",
                               "میںارب": "میں ارب",
                               "میںاردو": "میں اردو",
                               "میںاسلام": "میں اسلام",
                               "میںاضافہ": "میں اضافہ",
                               "میںاضافے": "میں اضافے",
                               "میںامریکی": "میں امریکی",
                               "میںانتہائی": "میں انتہائی",
                               "میںانکشاف": "میں انکشاف",
                               "میںانہوں": "میں انہوں",
                               "میںاور": "میں اور",
                               "میںاپنی": "میں اپنی",
                               "میںایسا": "میں ایسا",
                               "میںایم": "میں ایم",
                               "میںبات": "میں بات",
                               "میںبتایا": "میں بتایا",
                               "میںبدل": "میں بدل",
                               "میںبند": "میں بند",
                               "میںبڑی": "میں بڑی",
                               "میںبڑے": "میں بڑے",
                               "میںبہت": "میں بہت",
                               "میںبہتری": "میں بہتری",
                               "میںبیٹھ": "میں بیٹھ",
                               "میںبیٹھے": "میں بیٹھے",
                               "میںبے": "میں بے",
                               "میںتاخیر": "میں تاخیر",
                               "میںترمیم": "میں ترمیم",
                               "میںتعینات": "میں تعینات",
                               "میںتقریبا": "میں تقریبا",
                               "میںتو": "میں تو",
                               "میںتوسیع": "میں توسیع",
                               "میںتھا": "میں تھا",
                               "میںتھے": "میں تھے",
                               "میںتیزی": "میں تیزی",
                               "میںتیل": "میں تیل",
                               "میںجانے": "میں جانے",
                               "میںجب": "میں جب",
                               "میںجس": "میں جس",
                               "میںجمہوریت": "میں جمہوریت",
                               "میںجو": "میں جو",
                               "میںجگہ": "میں جگہ",
                               "میںجہاں": "میں جہاں",
                               "میںداخل": "میں داخل",
                               "میںدرد": "میں درد",
                               "میںدس": "میں دس",
                               "میںدلچسپی": "میں دلچسپی",
                               "میںدنیا": "میں دنیا",
                               "میںدو": "میں دو",
                               "میںدہشت": "میں دہشت",
                               "میںدیکھا": "میں دیکھا",
                               "میںرنز": "میں رنز",
                               "میںرکاوٹ": "میں رکاوٹ",
                               "میںرکھ": "میں رکھ",
                               "میںرکھا": "میں رکھا",
                               "میںرہ": "میں رہ",
                               "میںرہتے": "میں رہتے",
                               "میںزیادہ": "میں زیادہ",
                               "میںزیر": "میں زیر",
                               "میںسابق": "میں سابق",
                               "میںسال": "میں سال",
                               "میںسب": "میں سب",
                               "میںسرمایہ": "میں سرمایہ",
                               "میںسوار": "میں سوار",
                               "میںسی": "میں سی",
                               "میںسیاسی": "میں سیاسی",
                               "میںسیلاب": "میں سیلاب",
                               "میںشادی": "میں شادی",
                               "میںشدت": "میں شدت",
                               "میںشروع": "میں شروع",
                               "میںشرکت": "میں شرکت",
                               "میںشکست": "میں شکست",
                               "میںصرف": "میں صرف",
                               "میںطالبان": "میں طالبان",
                               "میںعام": "میں عام",
                               "میںفرق": "میں فرق",
                               "میںفروخت": "میں فروخت",
                               "میںفوجی": "میں فوجی",
                               "میںفی": "میں فی",
                               "میںقدم": "میں قدم",
                               "میںقومی": "میں قومی",
                               "میںقیام": "میں قیام",
                               "میںقید": "میں قید",
                               "میںلانے": "میں لانے",
                               "میںلاکھ": "میں لاکھ",
                               "میںلایا": "میں لایا",
                               "میںلوگ": "میں لوگ",
                               "میںلوگوں": "میں لوگوں",
                               "میںلیا": "میں لیا",
                               "میںلے": "میں لے",
                               "میںمبتلا": "میں مبتلا",
                               "میںمتعدد": "میں متعدد",
                               "میںمداخلت": "میں مداخلت",
                               "میںمدد": "میں مدد",
                               "میںمددگار": "میں مددگار",
                               "میںمزید": "میں مزید",
                               "میںمسلسل": "میں مسلسل",
                               "میںمصروف": "میں مصروف",
                               "میںملوث": "میں ملوث",
                               "میںمنتقل": "میں منتقل",
                               "میںمنعقد": "میں منعقد",
                               "میںموسم": "میں موسم",
                               "میںموقف": "میں موقف",
                               "میںمکمل": "میں مکمل",
                               "میںمیڈیا": "میں میڈیا",
                               "میںنمایاں": "میں نمایاں",
                               "میںنواز": "میں نواز",
                               "میںنہ": "میں نہ",
                               "میںنہیں": "میں نہیں",
                               "میںوہ": "میں وہ",
                               "میںپائے": "میں پائے",
                               "میںپانچ": "میں پانچ",
                               "میںپاک": "میں پاک",
                               "میںپریس": "میں پریس",
                               "میںپیش": "میں پیش",
                               "میںپیپلز": "میں پیپلز",
                               "میںچار": "میں چار",
                               "میںکئی": "میں کئی",
                               "میںکافی": "میں کافی",
                               "میںکام": "میں کام",
                               "میںکامیاب": "میں کامیاب",
                               "میںکر": "میں کر",
                               "میںکرپشن": "میں کرپشن",
                               "میںکسی": "میں کسی",
                               "میںکمی": "میں کمی",
                               "میںکو": "میں کو",
                               "میںکچھ": "میں کچھ",
                               "میںکھیلے": "میں کھیلے",
                               "میںکہیں": "میں کہیں",
                               "میںکیا": "میں کیا",
                               "میںگزشتہ": "میں گزشتہ",
                               "میںہر": "میں ہر",
                               "میںہزار": "میں ہزار",
                               "میںہزاروں": "میں ہزاروں",
                               "میںہلاک": "میں ہلاک",
                               "میںہمارے": "میں ہمارے",
                               "میںہو": "میں ہو",
                               "میںہوئی": "میں ہوئی",
                               "میںہوں": "میں ہوں",
                               "میںہی": "میں ہی",
                               "میںہیں": "میں ہیں",
                               "میںہے": "میں ہے",
                               "نلیگ": "ن لیگ",
                               "نئینسل": "نئی نسل",
                               "نائبصدر": "نائب صدر",
                               "نائنالیون": "نائن الیون",
                               "نافذکر": "نافذ کر",
                               "نافذکرنے": "نافذ کرنے",
                               "نامبھی": "نام بھی",
                               "نامسے": "نام سے",
                               "نامپر": "نام پر",
                               "نامکی": "نام کی",
                               "نامہے": "نام ہے",
                               "نامعلومافراد": "نامعلوم افراد",
                               "ناکامہو": "ناکام ہو",
                               "نتیجہمیں": "نتیجہ میں",
                               "نثارعلی": "نثار علی",
                               "نثارنے": "نثار نے",
                               "نجمسیٹھی": "نجم سیٹھی",
                               "نریندرمودی": "نریندر مودی",
                               "نشانہبنا": "نشانہ بنا",
                               "نشانہبنانے": "نشانہ بنانے",
                               "نشانہبنایا": "نشانہ بنایا",
                               "نظامکی": "نظام کی",
                               "نظامکے": "نظام کے",
                               "نظرآ": "نظر آ",
                               "نظرآنے": "نظر آنے",
                               "نظرثانی": "نظر ثانی",
                               "نظرسے": "نظر سے",
                               "نظرمیں": "نظر میں",
                               "نظروںسے": "نظروں سے",
                               "نظریہپاکستان": "نظریہ پاکستان",
                               "نظیربھٹو": "نظیر بھٹو",
                               "نقصاننہیں": "نقصان نہیں",
                               "نقصانپہنچانے": "نقصان پہنچانے",
                               "نقصانہو": "نقصان ہو",
                               "نقطہنظر": "نقطہ نظر",
                               "نقلمکانی": "نقل مکانی",
                               "نمازجنازہ": "نماز جنازہ",
                               "نمبرپر": "نمبر پر",
                               "نمٹنےکے": "نمٹنے کے",
                               "نوازنے": "نواز نے",
                               "نوجوان": "نوجو ان",
                               "نوجوانوں": "نوجو انوں",
                               "نوربصیرت": "نور بصیرت",
                               "نوعیتکے": "نوعیت کے",
                               "نومبرء": "نومبر ء",
                               "نومبرکو": "نومبر کو",
                               "نوٹسجاری": "نوٹس جاری",
                               "نکالدیا": "نکال دیا",
                               "نکلآئے": "نکل آئے",
                               "نکلکر": "نکل کر",
                               "نہآئے": "نہ آئے",
                               "نہتھے": "نہ تھے",
                               "نہدے": "نہ دے",
                               "نہملنے": "نہ ملنے",
                               "نہکرنا": "نہ کرنا",
                               "نہکرنے": "نہ کرنے",
                               "نہکرے": "نہ کرے",
                               "نہکو": "نہ کو",
                               "نہکیا": "نہ کیا",
                               "نہہوئی": "نہ ہوئی",
                               "نہہوا": "نہ ہوا",
                               "نہہوتا": "نہ ہوتا",
                               "نہہی": "نہ ہی",
                               "نہیںآ": "نہیں آ",
                               "نہیںآئی": "نہیں آئی",
                               "نہیںآئے": "نہیں آئے",
                               "نہیںآتے": "نہیں آتے",
                               "نہیںاور": "نہیں اور",
                               "نہیںبن": "نہیں بن",
                               "نہیںتھا": "نہیں تھا",
                               "نہیںجا": "نہیں جا",
                               "نہیںجانتے": "نہیں جانتے",
                               "نہیںجو": "نہیں جو",
                               "نہیںدیتا": "نہیں دیتا",
                               "نہیںدیتے": "نہیں دیتے",
                               "نہیںدیکھا": "نہیں دیکھا",
                               "نہیںرکھتے": "نہیں رکھتے",
                               "نہیںرہ": "نہیں رہ",
                               "نہیںرہی": "نہیں رہی",
                               "نہیںرہے": "نہیں رہے",
                               "نہیںسکتا": "نہیں سکتا",
                               "نہیںسکتے": "نہیں سکتے",
                               "نہیںلیا": "نہیں لیا",
                               "نہیںلیکن": "نہیں لیکن",
                               "نہیںلے": "نہیں لے",
                               "نہیںمل": "نہیں مل",
                               "نہیںملا": "نہیں ملا",
                               "نہیںملتی": "نہیں ملتی",
                               "نہیںملی": "نہیں ملی",
                               "نہیںملے": "نہیں ملے",
                               "نہیںمگر": "نہیں مگر",
                               "نہیںچاہتے": "نہیں چاہتے",
                               "نہیںکئے": "نہیں کئے",
                               "نہیںکرتی": "نہیں کرتی",
                               "نہیںکرے": "نہیں کرے",
                               "نہیںکہا": "نہیں کہا",
                               "نہیںکی": "نہیں کی",
                               "نہیںکیونکہ": "نہیں کیونکہ",
                               "نہیںہوئے": "نہیں ہوئے",
                               "نہیںہوا": "نہیں ہوا",
                               "نہیںہوتا": "نہیں ہوتا",
                               "نہیںہوتی": "نہیں ہوتی",
                               "نہیںہونا": "نہیں ہونا",
                               "نہیںہیں": "نہیں ہیں",
                               "نہیںیہ": "نہیں یہ",
                               "نیبنے": "نیب نے",
                               "نیبکی": "نیب کی",
                               "نیبکے": "نیب کے",
                               "نیوزکے": "نیوز کے",
                               "نےء": "نے ء",
                               "نےآج": "نے آج",
                               "نےاب": "نے اب",
                               "نےاسلام": "نے اسلام",
                               "نےاسے": "نے اسے",
                               "نےاعتراف": "نے اعتراف",
                               "نےاعلان": "نے اعلان",
                               "نےافغانستان": "نے افغانستان",
                               "نےالزام": "نے الزام",
                               "نےانکشاف": "نے انکشاف",
                               "نےانہیں": "نے انہیں",
                               "نےاور": "نے اور",
                               "نےایسا": "نے ایسا",
                               "نےبھارتی": "نے بھارتی",
                               "نےبے": "نے بے",
                               "نےتمام": "نے تمام",
                               "نےتین": "نے تین",
                               "نےجا": "نے جا",
                               "نےجس": "نے جس",
                               "نےخود": "نے خود",
                               "نےدنیا": "نے دنیا",
                               "نےدہشت": "نے دہشت",
                               "نےدیا": "نے دیا",
                               "نےدیکھا": "نے دیکھا",
                               "نےریمارکس": "نے ریمارکس",
                               "نےسابق": "نے سابق",
                               "نےسب": "نے سب",
                               "نےسوچا": "نے سوچا",
                               "نےسے": "نے سے",
                               "نےشرکت": "نے شرکت",
                               "نےصدر": "نے صدر",
                               "نےصرف": "نے صرف",
                               "نےعمران": "نے عمران",
                               "نےعوام": "نے عوام",
                               "نےفیصلہ": "نے فیصلہ",
                               "نےقومی": "نے قومی",
                               "نےلگے": "نے لگے",
                               "نےمجھ": "نے مجھ",
                               "نےمزید": "نے مزید",
                               "نےمیڈیا": "نے میڈیا",
                               "نےنہ": "نے نہ",
                               "نےنہیں": "نے نہیں",
                               "نےواضح": "نے واضح",
                               "نےوالا": "نے والا",
                               "نےوالوں": "نے والوں",
                               "نےوالی": "نے والی",
                               "نےوالے": "نے والے",
                               "نےوہ": "نے وہ",
                               "نےپاکستان": "نے پاکستان",
                               "نےپاکستانی": "نے پاکستانی",
                               "نےپر": "نے پر",
                               "نےپوچھا": "نے پوچھا",
                               "نےپہلی": "نے پہلی",
                               "نےپی": "نے پی",
                               "نےکئی": "نے کئی",
                               "نےکا": "نے کا",
                               "نےکسی": "نے کسی",
                               "نےکو": "نے کو",
                               "نےکچھ": "نے کچھ",
                               "نےگذشتہ": "نے گذشتہ",
                               "نےہر": "نے ہر",
                               "نےہمیشہ": "نے ہمیشہ",
                               "نےہمیں": "نے ہمیں",
                               "نےہی": "نے ہی",
                               "وانصاف": "و انصاف",
                               "ودیگر": "و دیگر",
                               "وشمار": "و شمار",
                               "وغریب": "و غریب",
                               "وقوم": "و قوم",
                               "وکشمیر": "و کشمیر",
                               "وائیفائی": "وائی فائی",
                               "واشنگٹنمیں": "واشنگٹن میں",
                               "واضحطور": "واضح طور",
                               "واضحنہیں": "واضح نہیں",
                               "واضحکر": "واضح کر",
                               "واضحہو": "واضح ہو",
                               "واقعہو": "واقع ہو",
                               "واقعہے": "واقع ہے",
                               "واقعہکی": "واقعہ کی",
                               "واقعہکے": "واقعہ کے",
                               "واقعےکی": "واقعے کی",
                               "واقعےکے": "واقعے کے",
                               "والدینکو": "والدین کو",
                               "والدینکی": "والدین کی",
                               "والدینکے": "والدین کے",
                               "والوںسے": "والوں سے",
                               "والوںکو": "والوں کو",
                               "والوںکی": "والوں کی",
                               "والوںکے": "والوں کے",
                               "والیاس": "والی اس",
                               "والیفلم": "والی فلم",
                               "والےاداروں": "والے اداروں",
                               "والےافراد": "والے افراد",
                               "والےشخص": "والے شخص",
                               "والےکو": "والے کو",
                               "والےہیں": "والے ہیں",
                               "واپسآ": "واپس آ",
                               "واپسلے": "واپس لے",
                               "واپسیپر": "واپسی پر",
                               "واپسیکا": "واپسی کا",
                               "واپسیکے": "واپسی کے",
                               "وجہہے": "وجہ ہے",
                               "ورلڈٹی": "ورلڈ ٹی",
                               "وزنمیں": "وزن میں",
                               "وزنکم": "وزن کم",
                               "وزیراطلاعات": "وزیر اطلاعات",
                               "وزیراعلی": "وزیر اعلی",
                               "وزیرخارجہ": "وزیر خارجہ",
                               "وزیرداخلہ": "وزیر داخلہ",
                               "وزیرمملکت": "وزیر مملکت",
                               "وصولکر": "وصول کر",
                               "وطنواپس": "وطن واپس",
                               "وعدہکیا": "وعدہ کیا",
                               "وفاقیوزیر": "وفاقی وزیر",
                               "وفاقیکابینہ": "وفاقی کابینہ",
                               "وقتآ": "وقت آ",
                               "وقتسے": "وقت سے",
                               "وقتمیں": "وقت میں",
                               "وقتپر": "وقت پر",
                               "وقتکا": "وقت کا",
                               "وقتکے": "وقت کے",
                               "وقتہے": "وقت ہے",
                               "ووڈاداکارہ": "ووڈ اداکارہ",
                               "ووڈمیں": "ووڈ میں",
                               "ووڈکی": "ووڈ کی",
                               "ووڈکے": "ووڈ کے",
                               "وٹامنسی": "وٹامن سی",
                               "وکیلنے": "وکیل نے",
                               "وہآج": "وہ آج",
                               "وہاب": "وہ اب",
                               "وہاسے": "وہ اسے",
                               "وہان": "وہ ان",
                               "وہاپنا": "وہ اپنا",
                               "وہاپنی": "وہ اپنی",
                               "وہاپنے": "وہ اپنے",
                               "وہایک": "وہ ایک",
                               "وہبھی": "وہ بھی",
                               "وہبہت": "وہ بہت",
                               "وہبے": "وہ بے",
                               "وہتمام": "وہ تمام",
                               "وہجو": "وہ جو",
                               "وہصرف": "وہ صرف",
                               "وہملک": "وہ ملک",
                               "وہپہلے": "وہ پہلے",
                               "وہکو": "وہ کو",
                               "وہکچھ": "وہ کچھ",
                               "وہکہتے": "وہ کہتے",
                               "وہہر": "وہ ہر",
                               "وہہے": "وہ ہے",
                               "وہیہ": "وہ یہ",
                               "وہاںموجود": "وہاں موجود",
                               "وہاںپر": "وہاں پر",
                               "وہاںکے": "وہاں کے",
                               "ویپر": "وی پر",
                               "ویبسائٹ": "ویب سائٹ",
                               "ویبسائٹس": "ویب سائٹس",
                               "ویراتکوہلی": "ویرات کوہلی",
                               "ویسےبھی": "ویسے بھی",
                               "ویسےتو": "ویسے تو",
                               "ویڈیومیں": "ویڈیو میں",
                               "ٹوئٹرپر": "ٹوئٹر پر",
                               "ٹھیکہو": "ٹھیک ہو",
                               "ٹھیکہے": "ٹھیک ہے",
                               "ٹیآئی": "ٹی آئی",
                               "ٹیسی": "ٹی سی",
                               "ٹیٹونٹی": "ٹی ٹونٹی",
                               "ٹیکے": "ٹی کے",
                               "ٹیسٹمیچ": "ٹیسٹ میچ",
                               "ٹیسٹمیں": "ٹیسٹ میں",
                               "ٹیلیفون": "ٹیلی فون",
                               "ٹیلیویژن": "ٹیلی ویژن",
                               "ٹیمکا": "ٹیم کا",
                               "ٹیمکے": "ٹیم کے",
                               "ٹیموںکے": "ٹیموں کے",
                               "ٹیکنالوجیکے": "ٹیکنالوجی کے",
                               "پائپلائن": "پائپ لائن",
                               "پائےجاتے": "پائے جاتے",
                               "پارلیمنٹکو": "پارلیمنٹ کو",
                               "پارلیمنٹکی": "پارلیمنٹ کی",
                               "پارٹیاور": "پارٹی اور",
                               "پارٹیسے": "پارٹی سے",
                               "پارٹیکا": "پارٹی کا",
                               "پارٹیکی": "پارٹی کی",
                               "پالیسیپر": "پالیسی پر",
                               "پالیسیکے": "پالیسی کے",
                               "پانیکی": "پانی کی",
                               "پانےوالے": "پانے والے",
                               "پانےکے": "پانے کے",
                               "پاکافغان": "پاک افغان",
                               "پاکفوج": "پاک فوج",
                               "پاکچین": "پاک چین",
                               "پاکستانبھارت": "پاکستان بھارت",
                               "پاکستانتحریک": "پاکستان تحریک",
                               "پاکستانسپر": "پاکستان سپر",
                               "پاکستانسے": "پاکستان سے",
                               "پاکستاننے": "پاکستان نے",
                               "پاکستانپر": "پاکستان پر",
                               "پاکستانکیلئے": "پاکستان کیلئے",
                               "پاکستانیحکومت": "پاکستانی حکومت",
                               "پاکستانیروپے": "پاکستانی روپے",
                               "پاکستانیفوج": "پاکستانی فوج",
                               "پاکستانیٹیم": "پاکستانی ٹیم",
                               "پاکستانیوںکو": "پاکستانیوں کو",
                               "پاکستانیوںکی": "پاکستانیوں کی",
                               "پاکستانیوںکے": "پاکستانیوں کے",
                               "پتہنہیں": "پتہ نہیں",
                               "پتہچلا": "پتہ چلا",
                               "پرآ": "پر آ",
                               "پرآمادہ": "پر آمادہ",
                               "پرآنے": "پر آنے",
                               "پرآپ": "پر آپ",
                               "پراثر": "پر اثر",
                               "پراس": "پر اس",
                               "پراستعمال": "پر استعمال",
                               "پراسرار": "پر اسرار",
                               "پراسی": "پر اسی",
                               "پراسے": "پر اسے",
                               "پراعتماد": "پر اعتماد",
                               "پرالزام": "پر الزام",
                               "پرامریکی": "پر امریکی",
                               "پرامن": "پر امن",
                               "پران": "پر ان",
                               "پرانہوں": "پر انہوں",
                               "پرانہیں": "پر انہیں",
                               "پراور": "پر اور",
                               "پراپنا": "پر اپنا",
                               "پراپنے": "پر اپنے",
                               "پرایک": "پر ایک",
                               "پربحث": "پر بحث",
                               "پربھارت": "پر بھارت",
                               "پربھارتی": "پر بھارتی",
                               "پربیٹھ": "پر بیٹھ",
                               "پربے": "پر بے",
                               "پرتبادلہ": "پر تبادلہ",
                               "پرتشدد": "پر تشدد",
                               "پرتو": "پر تو",
                               "پرتیار": "پر تیار",
                               "پرجاری": "پر جاری",
                               "پرجو": "پر جو",
                               "پرحملہ": "پر حملہ",
                               "پرحکومت": "پر حکومت",
                               "پرخرچ": "پر خرچ",
                               "پرخود": "پر خود",
                               "پردو": "پر دو",
                               "پردہشت": "پر دہشت",
                               "پررنز": "پر رنز",
                               "پرزور": "پر زور",
                               "پرسخت": "پر سخت",
                               "پرسوار": "پر سوار",
                               "پرسے": "پر سے",
                               "پرشدید": "پر شدید",
                               "پرعائد": "پر عائد",
                               "پرعدالت": "پر عدالت",
                               "پرعمل": "پر عمل",
                               "پرفائرنگ": "پر فائرنگ",
                               "پرفائز": "پر فائز",
                               "پرقائم": "پر قائم",
                               "پرلگا": "پر لگا",
                               "پرمبنی": "پر مبنی",
                               "پرمجبور": "پر مجبور",
                               "پرمشتمل": "پر مشتمل",
                               "پرمنتقل": "پر منتقل",
                               "پرموجود": "پر موجود",
                               "پرمکمل": "پر مکمل",
                               "پرمیں": "پر میں",
                               "پرنہ": "پر نہ",
                               "پرواضح": "پر واضح",
                               "پرواقع": "پر واقع",
                               "پروزیر": "پر وزیر",
                               "پرپابندی": "پر پابندی",
                               "پرپورا": "پر پورا",
                               "پرپولیس": "پر پولیس",
                               "پرکام": "پر کام",
                               "پرکو": "پر کو",
                               "پرکچھ": "پر کچھ",
                               "پرکی": "پر کی",
                               "پرہاتھ": "پر ہاتھ",
                               "پرہم": "پر ہم",
                               "پرہو": "پر ہو",
                               "پرہی": "پر ہی",
                               "پرہیز": "پر ہیز",
                               "پرہے": "پر ہے",
                               "پریہ": "پر یہ",
                               "پرویزالہی": "پرویز الہی",
                               "پرویزمشرف": "پرویز مشرف",
                               "پرویزکی": "پرویز کی",
                               "پریانکا": "پریان کا",
                               "پریسکانفرنس": "پریس کانفرنس",
                               "پریشانہو": "پریشان ہو",
                               "پریشانیکا": "پریشانی کا",
                               "پسندکر": "پسند کر",
                               "پسندوںنے": "پسندوں نے",
                               "پسندوںکی": "پسندوں کی",
                               "پشاورزلمی": "پشاور زلمی",
                               "پشاورمیں": "پشاور میں",
                               "پشاورکے": "پشاور کے",
                               "پلیٹفارم": "پلیٹ فارم",
                               "پنجاباور": "پنجاب اور",
                               "پنجابشہباز": "پنجاب شہباز",
                               "پنجابمیاں": "پنجاب میاں",
                               "پنجابمیں": "پنجاب میں",
                               "پنجابنے": "پنجاب نے",
                               "پنجابکے": "پنجاب کے",
                               "پوراکر": "پورا کر",
                               "پوراکرنے": "پورا کرنے",
                               "پوریدنیا": "پوری دنیا",
                               "پوریکر": "پوری کر",
                               "پوریکرنے": "پوری کرنے",
                               "پوریہو": "پوری ہو",
                               "پولیساہلکار": "پولیس اہلکار",
                               "پولیساہلکاروں": "پولیس اہلکاروں",
                               "پولیسکی": "پولیس کی",
                               "پولیسکے": "پولیس کے",
                               "پوچھاکہ": "پوچھا کہ",
                               "پوچھاگیا": "پوچھا گیا",
                               "پٹرولیممصنوعات": "پٹرولیم مصنوعات",
                               "پڑاتھا": "پڑا تھا",
                               "پڑاہے": "پڑا ہے",
                               "پڑتاہے": "پڑتا ہے",
                               "پڑتیہے": "پڑتی ہے",
                               "پڑھکر": "پڑھ کر",
                               "پڑیہے": "پڑی ہے",
                               "پڑےگی": "پڑے گی",
                               "پکڑکر": "پکڑ کر",
                               "پھراس": "پھر اس",
                               "پھراسے": "پھر اسے",
                               "پھران": "پھر ان",
                               "پھرایک": "پھر ایک",
                               "پھربھی": "پھر بھی",
                               "پھرسے": "پھر سے",
                               "پھروہ": "پھر وہ",
                               "پھریہ": "پھر یہ",
                               "پہلیبار": "پہلی بار",
                               "پہلیمرتبہ": "پہلی مرتبہ",
                               "پہلےتو": "پہلے تو",
                               "پہلےسے": "پہلے سے",
                               "پہلےہی": "پہلے ہی",
                               "پہنکر": "پہن کر",
                               "پہنچکر": "پہنچ کر",
                               "پہنچگیا": "پہنچ گیا",
                               "پہنچادیا": "پہنچا دیا",
                               "پہنچاہے": "پہنچا ہے",
                               "پہنچنےکے": "پہنچنے کے",
                               "پہنچےتو": "پہنچے تو",
                               "پیاو": "پی او",
                               "پیایس": "پی ایس",
                               "پیایل": "پی ایل",
                               "پیسی": "پی سی",
                               "پیٹی": "پی ٹی",
                               "پیپی": "پی پی",
                               "پیکی": "پی کی",
                               "پیکے": "پی کے",
                               "پیدانہیں": "پیدا نہیں",
                               "پیداہو": "پیدا ہو",
                               "پیداہوئی": "پیدا ہوئی",
                               "پیداہوئے": "پیدا ہوئے",
                               "پیداہوا": "پیدا ہوا",
                               "پیداہوتا": "پیدا ہوتا",
                               "پیداہوتی": "پیدا ہوتی",
                               "پیرکو": "پیر کو",
                               "پیرکے": "پیر کے",
                               "پیشآنے": "پیش آنے",
                               "پیشنظر": "پیش نظر",
                               "پیشنہیں": "پیش نہیں",
                               "پیشکئے": "پیش کئے",
                               "پیشکر": "پیش کر",
                               "پیشکریں": "پیش کریں",
                               "پیشکی": "پیش کی",
                               "پیشکیا": "پیش کیا",
                               "پیشگوئی": "پیش گوئی",
                               "پیشہو": "پیش ہو",
                               "پیشکشکی": "پیشکش کی",
                               "پیغاممیں": "پیغام میں",
                               "پینےسے": "پینے سے",
                               "پینےکے": "پینے کے",
                               "پیٹمیں": "پیٹ میں",
                               "چارسال": "چار سال",
                               "چاہئےاور": "چاہئے اور",
                               "چاہئےتھا": "چاہئے تھا",
                               "چاہئےکہ": "چاہئے کہ",
                               "چاہتاتھا": "چاہتا تھا",
                               "چاہتاہے": "چاہتا ہے",
                               "چاہتیہیں": "چاہتی ہیں",
                               "چاہیںتو": "چاہیں تو",
                               "چاہیےاور": "چاہیے اور",
                               "چاہیےکہ": "چاہیے کہ",
                               "چلرہا": "چل رہا",
                               "چلرہی": "چل رہی",
                               "چلکر": "چل کر",
                               "چلاکہ": "چلا کہ",
                               "چلاگیا": "چلا گیا",
                               "چلتاہے": "چلتا ہے",
                               "چلیگئی": "چلی گئی",
                               "چلےجاتے": "چلے جاتے",
                               "چندماہ": "چند ماہ",
                               "چودھرینثار": "چودھری نثار",
                               "چوہدرینے": "چوہدری نے",
                               "چکیتھی": "چکی تھی",
                               "چکیہے": "چکی ہے",
                               "چھماہ": "چھ ماہ",
                               "چھوڑکر": "چھوڑ کر",
                               "چیئرمین": "چیئر مین",
                               "چیئرمینعمران": "چیئرمین عمران",
                               "چیئرمینپی": "چیئرمین پی",
                               "چیتکر": "چیت کر",
                               "چیتکی": "چیت کی",
                               "چیتکے": "چیت کے",
                               "چیزہے": "چیز ہے",
                               "چیفآف": "چیف آف",
                               "چیفایگزیکٹو": "چیف ایگزیکٹو",
                               "چینسے": "چین سے",
                               "چیننے": "چین نے",
                               "چینکے": "چین کے",
                               "ڈالدیا": "ڈال دیا",
                               "ڈالکر": "ڈال کر",
                               "ڈالرتقریبا": "ڈالر تقریبا",
                               "ڈالرکا": "ڈالر کا",
                               "ڈالرکے": "ڈالر کے",
                               "ڈالنےکی": "ڈالنے کی",
                               "ڈاکٹرمحمد": "ڈاکٹر محمد",
                               "ڈاکٹروںنے": "ڈاکٹروں نے",
                               "ڈونلڈٹرمپ": "ڈونلڈ ٹرمپ",
                               "ڈگریسینٹی": "ڈگری سینٹی",
                               "ڈیآئی": "ڈی آئی",
                               "ڈیایس": "ڈی ایس",
                               "ڈیاین": "ڈی این",
                               "ڈیاے": "ڈی اے",
                               "ڈیسی": "ڈی سی",
                               "ڈیپی": "ڈی پی",
                               "کئیسال": "کئی سال",
                               "کئےبغیر": "کئے بغیر",
                               "کئےتھے": "کئے تھے",
                               "کئےجاتے": "کئے جاتے",
                               "کئےگئے": "کئے گئے",
                               "کئےہوئے": "کئے ہوئے",
                               "کاآخری": "کا آخری",
                               "کاآغاز": "کا آغاز",
                               "کااثر": "کا اثر",
                               "کااختیار": "کا اختیار",
                               "کااس": "کا اس",
                               "کااصل": "کا اصل",
                               "کااطلاق": "کا اطلاق",
                               "کااعزاز": "کا اعزاز",
                               "کاامکان": "کا امکان",
                               "کاانتظام": "کا انتظام",
                               "کاانعقاد": "کا انعقاد",
                               "کااور": "کا اور",
                               "کااپنا": "کا اپنا",
                               "کااہم": "کا اہم",
                               "کاباعث": "کا باعث",
                               "کابحران": "کا بحران",
                               "کابنیادی": "کا بنیادی",
                               "کابڑا": "کا بڑا",
                               "کابہت": "کا بہت",
                               "کابہترین": "کا بہترین",
                               "کابیان": "کا بیان",
                               "کابیٹا": "کا بیٹا",
                               "کاتجربہ": "کا تجربہ",
                               "کاتجزیہ": "کا تجزیہ",
                               "کاتحفظ": "کا تحفظ",
                               "کاتذکرہ": "کا تذکرہ",
                               "کاتصور": "کا تصور",
                               "کاتعلق": "کا تعلق",
                               "کاتعین": "کا تعین",
                               "کاتو": "کا تو",
                               "کاتھا": "کا تھا",
                               "کاتیل": "کا تیل",
                               "کاجائزہ": "کا جائزہ",
                               "کاجواب": "کا جواب",
                               "کاحامل": "کا حامل",
                               "کاحصول": "کا حصول",
                               "کاحصہ": "کا حصہ",
                               "کاحق": "کا حق",
                               "کاحوالہ": "کا حوالہ",
                               "کاحکم": "کا حکم",
                               "کاخاتمہ": "کا خاتمہ",
                               "کاخطرہ": "کا خطرہ",
                               "کاخواب": "کا خواب",
                               "کاخون": "کا خون",
                               "کاخیال": "کا خیال",
                               "کادائرہ": "کا دائرہ",
                               "کادفاع": "کا دفاع",
                               "کادل": "کا دل",
                               "کادن": "کا دن",
                               "کادور": "کا دور",
                               "کادورہ": "کا دورہ",
                               "کادوسرا": "کا دوسرا",
                               "کاذریعہ": "کا ذریعہ",
                               "کاذمہ": "کا ذمہ",
                               "کاذکر": "کا ذکر",
                               "کارجحان": "کا رجحان",
                               "کارس": "کا رس",
                               "کارنگ": "کا رنگ",
                               "کارویہ": "کا رویہ",
                               "کاریکارڈ": "کا ریکارڈ",
                               "کازیادہ": "کا زیادہ",
                               "کاسامان": "کا سامان",
                               "کاسب": "کا سب",
                               "کاسر": "کا سر",
                               "کاسفر": "کا سفر",
                               "کاسلسلہ": "کا سلسلہ",
                               "کاسہارا": "کا سہارا",
                               "کاشمار": "کا شمار",
                               "کاشوق": "کا شوق",
                               "کاشکریہ": "کا شکریہ",
                               "کاطریقہ": "کا طریقہ",
                               "کاعزم": "کا عزم",
                               "کاعندیہ": "کا عندیہ",
                               "کافائدہ": "کا فائدہ",
                               "کافرض": "کا فرض",
                               "کافی": "کا فی",
                               "کاقتل": "کا قتل",
                               "کاقیام": "کا قیام",
                               "کامالک": "کا مالک",
                               "کامرکز": "کا مرکز",
                               "کامطالبہ": "کا مطالبہ",
                               "کامطالعہ": "کا مطالعہ",
                               "کامطلب": "کا مطلب",
                               "کامظاہرہ": "کا مظاہرہ",
                               "کامعاہدہ": "کا معاہدہ",
                               "کامقصد": "کا مقصد",
                               "کامنہ": "کا منہ",
                               "کاموقع": "کا موقع",
                               "کاموقف": "کا موقف",
                               "کانشانہ": "کا نشانہ",
                               "کانظام": "کا نظام",
                               "کانعرہ": "کا نعرہ",
                               "کانقصان": "کا نقصان",
                               "کانوٹس": "کا نوٹس",
                               "کانہیں": "کا نہیں",
                               "کانیا": "کا نیا",
                               "کاواحد": "کا واحد",
                               "کاواقعہ": "کا واقعہ",
                               "کاوجود": "کا وجود",
                               "کاوزن": "کا وزن",
                               "کاوعدہ": "کا وعدہ",
                               "کاپاکستان": "کا پاکستان",
                               "کاپورا": "کا پورا",
                               "کاپیغام": "کا پیغام",
                               "کاچمچ": "کا چمچ",
                               "کاچمچہ": "کا چمچہ",
                               "کاچہرہ": "کا چہرہ",
                               "کاکام": "کا کام",
                               "کاکردار": "کا کردار",
                               "کاکو": "کا کو",
                               "کاکہا": "کا کہا",
                               "کاہدف": "کا ہدف",
                               "کاہو": "کا ہو",
                               "کاہی": "کا ہی",
                               "کاہے": "کا ہے",
                               "کابلمیں": "کابل میں",
                               "کابینہکے": "کابینہ کے",
                               "کارنہیں": "کار نہیں",
                               "کارکر": "کار کر",
                               "کارکیا": "کار کیا",
                               "کارکے": "کار کے",
                               "کارروائیمیں": "کارروائی میں",
                               "کارروائیکا": "کارروائی کا",
                               "کارروائیکر": "کارروائی کر",
                               "کارروائیکے": "کارروائی کے",
                               "کارروائیوںمیں": "کارروائیوں میں",
                               "کاروںکا": "کاروں کا",
                               "کاروںکو": "کاروں کو",
                               "کارکنوںکو": "کارکنوں کو",
                               "کاریکے": "کاری کے",
                               "کامشروع": "کام شروع",
                               "کاممیں": "کام میں",
                               "کامکر": "کام کر",
                               "کامکرتا": "کام کرتا",
                               "کامکرتی": "کام کرتی",
                               "کامکرنے": "کام کرنے",
                               "کامکریں": "کام کریں",
                               "کامکی": "کام کی",
                               "کامکے": "کام کے",
                               "کامہے": "کام ہے",
                               "کامیابنہیں": "کامیاب نہیں",
                               "کامیابیسے": "کامیابی سے",
                               "کامیابیکے": "کامیابی کے",
                               "کاٹکر": "کاٹ کر",
                               "کبتک": "کب تک",
                               "کبھیکبھی": "کبھی کبھی",
                               "کبھیکسی": "کبھی کسی",
                               "کتابمیں": "کتاب میں",
                               "کترینہکیف": "کترینہ کیف",
                               "کرآپ": "کر آپ",
                               "کراس": "کر اس",
                               "کرانا": "کر انا",
                               "کرانہیں": "کر انہیں",
                               "کرانے": "کر انے",
                               "کراور": "کر اور",
                               "کرخود": "کر خود",
                               "کردئیے": "کر دئیے",
                               "کردیئے": "کر دیئے",
                               "کردینا": "کر دینا",
                               "کردینے": "کر دینے",
                               "کردیں": "کر دیں",
                               "کررکھ": "کر رکھ",
                               "کررکھی": "کر رکھی",
                               "کررہے": "کر رہے",
                               "کرسکتا": "کر سکتا",
                               "کرلیا": "کر لیا",
                               "کرلیتے": "کر لیتے",
                               "کرنہیں": "کر نہیں",
                               "کروہ": "کر وہ",
                               "کرپاکستان": "کر پاکستان",
                               "کرچکا": "کر چکا",
                               "کرچکی": "کر چکی",
                               "کرڈالا": "کر ڈالا",
                               "کرکام": "کر کام",
                               "کرکہا": "کر کہا",
                               "کرگئے": "کر گئے",
                               "کرہی": "کر ہی",
                               "کریہ": "کر یہ",
                               "کرائیگئی": "کرائی گئی",
                               "کراچیسے": "کراچی سے",
                               "کراچیمیں": "کراچی میں",
                               "کراچیکی": "کراچی کی",
                               "کرایاجا": "کرایا جا",
                               "کرایاگیا": "کرایا گیا",
                               "کرتارہا": "کرتا رہا",
                               "کرتیتھی": "کرتی تھی",
                               "کرتیرہی": "کرتی رہی",
                               "کرتیہوں": "کرتی ہوں",
                               "کرتیہیں": "کرتی ہیں",
                               "کردارادا": "کردار ادا",
                               "کردگیکا": "کردگی کا",
                               "کرماللہ": "کرم اللہ",
                               "کرنااور": "کرنا اور",
                               "کرنابھی": "کرنا بھی",
                               "کرناتھا": "کرنا تھا",
                               "کرناپڑ": "کرنا پڑ",
                               "کرناپڑتا": "کرنا پڑتا",
                               "کرناپڑے": "کرنا پڑے",
                               "کرناچاہتی": "کرنا چاہتی",
                               "کرناچاہتے": "کرنا چاہتے",
                               "کرنیچاہئے": "کرنی چاہئے",
                               "کرنیچاہیے": "کرنی چاہیے",
                               "کرنےاور": "کرنے اور",
                               "کرنےلگے": "کرنے لگے",
                               "کرنےوالوں": "کرنے والوں",
                               "کرنےوالی": "کرنے والی",
                               "کروڑعوام": "کروڑ عوام",
                               "کروڑڈالر": "کروڑ ڈالر",
                               "کروڑوںروپے": "کروڑوں روپے",
                               "کرپشناور": "کرپشن اور",
                               "کرپشنکی": "کرپشن کی",
                               "کرکٹمیں": "کرکٹ میں",
                               "کرکٹٹیم": "کرکٹ ٹیم",
                               "کرکٹکے": "کرکٹ کے",
                               "کریںاور": "کریں اور",
                               "کریںتا": "کریں تا",
                               "کریںکیونکہ": "کریں کیونکہ",
                               "کرےتو": "کرے تو",
                               "کرےکہ": "کرے کہ",
                               "کرےگا": "کرے گا",
                               "کرےگی": "کرے گی",
                               "کسطرح": "کس طرح",
                               "کسقدر": "کس قدر",
                               "کسکی": "کس کی",
                               "کسکے": "کس کے",
                               "کسیاور": "کسی اور",
                               "کسیحد": "کسی حد",
                               "کسیدوسرے": "کسی دوسرے",
                               "کسیصورت": "کسی صورت",
                               "کسینہ": "کسی نہ",
                               "کسینے": "کسی نے",
                               "کسیکا": "کسی کا",
                               "کسیکو": "کسی کو",
                               "کشحملوں": "کش حملوں",
                               "کشحملہ": "کش حملہ",
                               "کشحملے": "کش حملے",
                               "کشمیراور": "کشمیر اور",
                               "کشمیرمیں": "کشمیر میں",
                               "کشمیرکے": "کشمیر کے",
                               "کشمیریوںکو": "کشمیریوں کو",
                               "کشمیریوںکی": "کشمیریوں کی",
                               "کشیکر": "کشی کر",
                               "کشیکی": "کشی کی",
                               "کلثومنواز": "کلثوم نواز",
                               "کلنٹننے": "کلنٹن نے",
                               "کلومیٹر": "کلو میٹر",
                               "کماز": "کم از",
                               "کمعمر": "کم عمر",
                               "کمزورہو": "کمزور ہو",
                               "کمپنیکا": "کمپنی کا",
                               "کمپنیکی": "کمپنی کی",
                               "کمپنیوںکے": "کمپنیوں کے",
                               "کمینہیں": "کمی نہیں",
                               "کمیواقع": "کمی واقع",
                               "کمیکا": "کمی کا",
                               "کمیکی": "کمی کی",
                               "کمیکے": "کمی کے",
                               "کمیہو": "کمی ہو",
                               "کمیشننے": "کمیشن نے",
                               "کمیشنکی": "کمیشن کی",
                               "کمیٹیکا": "کمیٹی کا",
                               "کمیٹیکو": "کمیٹی کو",
                               "کمیٹیکی": "کمیٹی کی",
                               "کمیٹیکے": "کمیٹی کے",
                               "کوآگ": "کو آگ",
                               "کوآگاہ": "کو آگاہ",
                               "کوآگے": "کو آگے",
                               "کواب": "کو اب",
                               "کواسلام": "کو اسلام",
                               "کواعتماد": "کو اعتماد",
                               "کوامریکہ": "کو امریکہ",
                               "کوامریکی": "کو امریکی",
                               "کوان": "کو ان",
                               "کوانٹرویو": "کو انٹرویو",
                               "کواور": "کو اور",
                               "کواپنا": "کو اپنا",
                               "کواپنی": "کو اپنی",
                               "کواچھی": "کو اچھی",
                               "کوبتایا": "کو بتایا",
                               "کوبحال": "کو بحال",
                               "کوبرقرار": "کو برقرار",
                               "کوبند": "کو بند",
                               "کوبچانے": "کو بچانے",
                               "کوبھارت": "کو بھارت",
                               "کوبے": "کو بے",
                               "کوتباہ": "کو تباہ",
                               "کوتبدیل": "کو تبدیل",
                               "کوتحفظ": "کو تحفظ",
                               "کوترجیح": "کو ترجیح",
                               "کوجاری": "کو جاری",
                               "کوجب": "کو جب",
                               "کوجس": "کو جس",
                               "کوجنم": "کو جنم",
                               "کوحاصل": "کو حاصل",
                               "کوحراست": "کو حراست",
                               "کوحل": "کو حل",
                               "کوحکم": "کو حکم",
                               "کوختم": "کو ختم",
                               "کوخط": "کو خط",
                               "کوخود": "کو خود",
                               "کوخوش": "کو خوش",
                               "کودرپیش": "کو درپیش",
                               "کودنیا": "کو دنیا",
                               "کودو": "کو دو",
                               "کودوبارہ": "کو دوبارہ",
                               "کودور": "کو دور",
                               "کودی": "کو دی",
                               "کودیکھا": "کو دیکھا",
                               "کودیکھتے": "کو دیکھتے",
                               "کودیکھنے": "کو دیکھنے",
                               "کوزندہ": "کو زندہ",
                               "کوسب": "کو سب",
                               "کوسخت": "کو سخت",
                               "کوسزا": "کو سزا",
                               "کوسمجھنے": "کو سمجھنے",
                               "کوشامل": "کو شامل",
                               "کوصاف": "کو صاف",
                               "کوصرف": "کو صرف",
                               "کوطلب": "کو طلب",
                               "کوقبول": "کو قبول",
                               "کوقومی": "کو قومی",
                               "کولے": "کو لے",
                               "کومتاثر": "کو متاثر",
                               "کومحفوظ": "کو محفوظ",
                               "کومدنظر": "کو مدنظر",
                               "کوملک": "کو ملک",
                               "کومکمل": "کو مکمل",
                               "کومیں": "کو میں",
                               "کوناکام": "کو ناکام",
                               "کونظر": "کو نظر",
                               "کووزیر": "کو وزیر",
                               "کوووٹ": "کو ووٹ",
                               "کووہ": "کو وہ",
                               "کوپاکستان": "کو پاکستان",
                               "کوپتہ": "کو پتہ",
                               "کوپسند": "کو پسند",
                               "کوپورا": "کو پورا",
                               "کوپہلے": "کو پہلے",
                               "کوچاہئے": "کو چاہئے",
                               "کوچاہیے": "کو چاہیے",
                               "کوچھوڑ": "کو چھوڑ",
                               "کوکبھی": "کو کبھی",
                               "کوکس": "کو کس",
                               "کوکسی": "کو کسی",
                               "کوکمزور": "کو کمزور",
                               "کوکنٹرول": "کو کنٹرول",
                               "کوکو": "کو کو",
                               "کوکہا": "کو کہا",
                               "کوگرفتار": "کو گرفتار",
                               "کوہدایت": "کو ہدایت",
                               "کوہلاک": "کو ہلاک",
                               "کوہم": "کو ہم",
                               "کوہمیشہ": "کو ہمیشہ",
                               "کوہو": "کو ہو",
                               "کوہے": "کو ہے",
                               "کویاد": "کو یاد",
                               "کویقین": "کو یقین",
                               "کویہ": "کو یہ",
                               "کوئٹہمیں": "کوئٹہ میں",
                               "کورٹمیں": "کورٹ میں",
                               "کورٹنے": "کورٹ نے",
                               "کورٹکی": "کورٹ کی",
                               "کورٹکے": "کورٹ کے",
                               "کوریاکے": "کوریا کے",
                               "کوششمیں": "کوشش میں",
                               "کونسا": "کون سا",
                               "کونسی": "کون سی",
                               "کونہے": "کون ہے",
                               "کونسلکی": "کونسل کی",
                               "کپمیں": "کپ میں",
                               "کپکے": "کپ کے",
                               "کپورنے": "کپور نے",
                               "کچھاس": "کچھ اس",
                               "کچھبھی": "کچھ بھی",
                               "کچھزیادہ": "کچھ زیادہ",
                               "کچھعرصہ": "کچھ عرصہ",
                               "کچھعرصے": "کچھ عرصے",
                               "کچھلوگ": "کچھ لوگ",
                               "کچھلوگوں": "کچھ لوگوں",
                               "کچھنہیں": "کچھ نہیں",
                               "کچھہی": "کچھ ہی",
                               "کھاتےہیں": "کھاتے ہیں",
                               "کھانےپینے": "کھانے پینے",
                               "کھانےکی": "کھانے کی",
                               "کھانےکے": "کھانے کے",
                               "کھلاڑیوںکی": "کھلاڑیوں کی",
                               "کھلاڑیوںکے": "کھلاڑیوں کے",
                               "کھولکر": "کھول کر",
                               "کھڑاہو": "کھڑا ہو",
                               "کھڑےہو": "کھڑے ہو",
                               "کھیلاجا": "کھیلا جا",
                               "کہء": "کہ ء",
                               "کہآئی": "کہ آئی",
                               "کہآج": "کہ آج",
                               "کہآخر": "کہ آخر",
                               "کہاب": "کہ اب",
                               "کہابھی": "کہ ابھی",
                               "کہاسرائیل": "کہ اسرائیل",
                               "کہاسلام": "کہ اسلام",
                               "کہاسے": "کہ اسے",
                               "کہافغان": "کہ افغان",
                               "کہاللہ": "کہ اللہ",
                               "کہامریکہ": "کہ امریکہ",
                               "کہانہوں": "کہ انہوں",
                               "کہانہیں": "کہ انہیں",
                               "کہانی": "کہ انی",
                               "کہانیاں": "کہ انیاں",
                               "کہاپنی": "کہ اپنی",
                               "کہایران": "کہ ایران",
                               "کہایسا": "کہ ایسا",
                               "کہایسے": "کہ ایسے",
                               "کہبعض": "کہ بعض",
                               "کہبلوچستان": "کہ بلوچستان",
                               "کہبھارت": "کہ بھارت",
                               "کہبہت": "کہ بہت",
                               "کہبے": "کہ بے",
                               "کہجب": "کہ جب",
                               "کہجس": "کہ جس",
                               "کہجو": "کہ جو",
                               "کہجیسے": "کہ جیسے",
                               "کہحضرت": "کہ حضرت",
                               "کہحکومت": "کہ حکومت",
                               "کہخواتین": "کہ خواتین",
                               "کہخود": "کہ خود",
                               "کہدو": "کہ دو",
                               "کہدوسری": "کہ دوسری",
                               "کہرواں": "کہ رواں",
                               "کہسابق": "کہ سابق",
                               "کہسب": "کہ سب",
                               "کہسعودی": "کہ سعودی",
                               "کہسندھ": "کہ سندھ",
                               "کہسپریم": "کہ سپریم",
                               "کہشاید": "کہ شاید",
                               "کہصرف": "کہ صرف",
                               "کہطالبان": "کہ طالبان",
                               "کہعالمی": "کہ عالمی",
                               "کہعدالت": "کہ عدالت",
                               "کہفلم": "کہ فلم",
                               "کہقومی": "کہ قومی",
                               "کہلوگ": "کہ لوگ",
                               "کہملزم": "کہ ملزم",
                               "کہملک": "کہ ملک",
                               "کہموجودہ": "کہ موجودہ",
                               "کہمیاں": "کہ میاں",
                               "کہمیرا": "کہ میرا",
                               "کہوزیر": "کہ وزیر",
                               "کہوفاقی": "کہ وفاقی",
                               "کہوہاں": "کہ وہاں",
                               "کہپاک": "کہ پاک",
                               "کہپنجاب": "کہ پنجاب",
                               "کہپہلے": "کہ پہلے",
                               "کہپیپلز": "کہ پیپلز",
                               "کہچین": "کہ چین",
                               "کہڈاکٹر": "کہ ڈاکٹر",
                               "کہکس": "کہ کس",
                               "کہکسی": "کہ کسی",
                               "کہکشمیر": "کہ کشمیر",
                               "کہکو": "کہ کو",
                               "کہکہیں": "کہ کہیں",
                               "کہکیا": "کہ کیا",
                               "کہگذشتہ": "کہ گذشتہ",
                               "کہہمارا": "کہ ہمارا",
                               "کہہمارے": "کہ ہمارے",
                               "کہہندوستان": "کہ ہندوستان",
                               "کہیہاں": "کہ یہاں",
                               "کہاتھا": "کہا تھا",
                               "کہاجاتا": "کہا جاتا",
                               "کیاان": "کیا ان",
                               "کیابلکہ": "کیا بلکہ",
                               "کیاتو": "کیا تو",
                               "کیاجا": "کیا جا",
                               "کیاجائیگا": "کیا جائیگا",
                               "کیاجاس": "کیا جاس",
                               "کیاجانا": "کیا جانا",
                               "کیاجب": "کیا جب",
                               "کیاجس": "کیا جس",
                               "کیاجو": "کیا جو",
                               "کیالیکن": "کیا لیکن",
                               "کیاکر": "کیا کر",
                               "کیاہو": "کیا ہو",
                               "کیریلوگر": "کیری لوگر",
                               "کیسمیں": "کیس میں",
                               "کیسکا": "کیس کا",
                               "کیسکی": "کیس کی",
                               "کیسکے": "کیس کے",
                               "کیلئےاس": "کیلئے اس",
                               "کیلئےاستعمال": "کیلئے استعمال",
                               "کیلئےپاکستان": "کیلئے پاکستان",
                               "کینسرکے": "کینسر کے",
                               "کیوایم": "کیو ایم",
                               "کیورٹیفورسز": "کیورٹی فورسز",
                               "کیےجا": "کیے جا",
                               "کیےجائیں": "کیے جائیں",
                               "کیےجاتے": "کیے جاتے",
                               "کیےگئے": "کیے گئے",
                               "کیےہیں": "کیے ہیں",
                               "کےآخر": "کے آخر",
                               "کےاتحاد": "کے اتحاد",
                               "کےاجلاس": "کے اجلاس",
                               "کےاحکامات": "کے احکامات",
                               "کےاختتام": "کے اختتام",
                               "کےاخراجات": "کے اخراجات",
                               "کےاراکین": "کے اراکین",
                               "کےاستحکام": "کے استحکام",
                               "کےاستعمال": "کے استعمال",
                               "کےاسے": "کے اسے",
                               "کےاعتبار": "کے اعتبار",
                               "کےاعلان": "کے اعلان",
                               "کےاعلی": "کے اعلی",
                               "کےاقدامات": "کے اقدامات",
                               "کےامراض": "کے امراض",
                               "کےامیدوار": "کے امیدوار",
                               "کےامیر": "کے امیر",
                               "کےان": "کے ان",
                               "کےانتخاب": "کے انتخاب",
                               "کےانتخابات": "کے انتخابات",
                               "کےانتقال": "کے انتقال",
                               "کےانہیں": "کے انہیں",
                               "کےاوقات": "کے اوقات",
                               "کےاپنی": "کے اپنی",
                               "کےاپنے": "کے اپنے",
                               "کےاہلکار": "کے اہلکار",
                               "کےاہلکاروں": "کے اہلکاروں",
                               "کےاہم": "کے اہم",
                               "کےایٹمی": "کے ایٹمی",
                               "کےبانی": "کے بانی",
                               "کےباہر": "کے باہر",
                               "کےبجا": "کے بجا",
                               "کےبحران": "کے بحران",
                               "کےبدلے": "کے بدلے",
                               "کےبعض": "کے بعض",
                               "کےبغیر": "کے بغیر",
                               "کےبل": "کے بل",
                               "کےبنیادی": "کے بنیادی",
                               "کےبھائی": "کے بھائی",
                               "کےبیانات": "کے بیانات",
                               "کےبیشتر": "کے بیشتر",
                               "کےبے": "کے بے",
                               "کےترجمان": "کے ترجمان",
                               "کےتعاون": "کے تعاون",
                               "کےتعلقات": "کے تعلقات",
                               "کےتمام": "کے تمام",
                               "کےتناظر": "کے تناظر",
                               "کےتیل": "کے تیل",
                               "کےجج": "کے جج",
                               "کےجذبات": "کے جذبات",
                               "کےجرم": "کے جرم",
                               "کےجو": "کے جو",
                               "کےجواب": "کے جواب",
                               "کےحامی": "کے حامی",
                               "کےحساب": "کے حساب",
                               "کےحصول": "کے حصول",
                               "کےحصے": "کے حصے",
                               "کےحق": "کے حق",
                               "کےحل": "کے حل",
                               "کےحملے": "کے حملے",
                               "کےحکام": "کے حکام",
                               "کےخاتمہ": "کے خاتمہ",
                               "کےخاتمے": "کے خاتمے",
                               "کےخاندان": "کے خاندان",
                               "کےخطرے": "کے خطرے",
                               "کےخواب": "کے خواب",
                               "کےخیال": "کے خیال",
                               "کےدارالحکومت": "کے دارالحکومت",
                               "کےدرد": "کے درد",
                               "کےدروازے": "کے دروازے",
                               "کےدفتر": "کے دفتر",
                               "کےدل": "کے دل",
                               "کےدلوں": "کے دلوں",
                               "کےدماغ": "کے دماغ",
                               "کےدو": "کے دو",
                               "کےدور": "کے دور",
                               "کےدورہ": "کے دورہ",
                               "کےدونوں": "کے دونوں",
                               "کےذرائع": "کے ذرائع",
                               "کےذہن": "کے ذہن",
                               "کےرد": "کے رد",
                               "کےروز": "کے روز",
                               "کےرہائشی": "کے رہائشی",
                               "کےزمانے": "کے زمانے",
                               "کےزیادہ": "کے زیادہ",
                               "کےسابق": "کے سابق",
                               "کےساتھی": "کے ساتھی",
                               "کےساتھیوں": "کے ساتھیوں",
                               "کےسارے": "کے سارے",
                               "کےسپرد": "کے سپرد",
                               "کےسیاسی": "کے سیاسی",
                               "کےسینئر": "کے سینئر",
                               "کےسیکرٹری": "کے سیکرٹری",
                               "کےسے": "کے سے",
                               "کےشریک": "کے شریک",
                               "کےشعبہ": "کے شعبہ",
                               "کےشعبے": "کے شعبے",
                               "کےشوہر": "کے شوہر",
                               "کےشکار": "کے شکار",
                               "کےشہر": "کے شہر",
                               "کےصدر": "کے صدر",
                               "کےضلع": "کے ضلع",
                               "کےعادی": "کے عادی",
                               "کےعلاج": "کے علاج",
                               "کےعلاقوں": "کے علاقوں",
                               "کےعلاقہ": "کے علاقہ",
                               "کےعلاقے": "کے علاقے",
                               "کےعوام": "کے عوام",
                               "کےعہدے": "کے عہدے",
                               "کےغیر": "کے غیر",
                               "کےفرائض": "کے فرائض",
                               "کےفروغ": "کے فروغ",
                               "کےفوری": "کے فوری",
                               "کےفیصلے": "کے فیصلے",
                               "کےقانون": "کے قانون",
                               "کےقبضے": "کے قبضے",
                               "کےقتل": "کے قتل",
                               "کےقریبی": "کے قریبی",
                               "کےقیام": "کے قیام",
                               "کےلحاظ": "کے لحاظ",
                               "کےلواحقین": "کے لواحقین",
                               "کےمابین": "کے مابین",
                               "کےمتعلق": "کے متعلق",
                               "کےمختلف": "کے مختلف",
                               "کےمریضوں": "کے مریضوں",
                               "کےمسئلے": "کے مسئلے",
                               "کےمسائل": "کے مسائل",
                               "کےمستقبل": "کے مستقبل",
                               "کےمسلمانوں": "کے مسلمانوں",
                               "کےمشہور": "کے مشہور",
                               "کےمشیر": "کے مشیر",
                               "کےمعاملات": "کے معاملات",
                               "کےمعاملے": "کے معاملے",
                               "کےمعاہدے": "کے معاہدے",
                               "کےمعروف": "کے معروف",
                               "کےمفاد": "کے مفاد",
                               "کےمفادات": "کے مفادات",
                               "کےمقابلے": "کے مقابلے",
                               "کےمقام": "کے مقام",
                               "کےملازمین": "کے ملازمین",
                               "کےملک": "کے ملک",
                               "کےمنافی": "کے منافی",
                               "کےمنصوبے": "کے منصوبے",
                               "کےموقع": "کے موقع",
                               "کےمیدان": "کے میدان",
                               "کےمیں": "کے میں",
                               "کےنائب": "کے نائب",
                               "کےنظام": "کے نظام",
                               "کےنعرے": "کے نعرے",
                               "کےنفاذ": "کے نفاذ",
                               "کےنمائندوں": "کے نمائندوں",
                               "کےنمائندے": "کے نمائندے",
                               "کےوالد": "کے والد",
                               "کےوزیر": "کے وزیر",
                               "کےوقت": "کے وقت",
                               "کےپانی": "کے پانی",
                               "کےپر": "کے پر",
                               "کےپروگرام": "کے پروگرام",
                               "کےپس": "کے پس",
                               "کےپیش": "کے پیش",
                               "کےپیٹ": "کے پیٹ",
                               "کےپیچھے": "کے پیچھے",
                               "کےچمچ": "کے چمچ",
                               "کےچیئرمین": "کے چیئرمین",
                               "کےڈائریکٹر": "کے ڈائریکٹر",
                               "کےکارکنوں": "کے کارکنوں",
                               "کےکسی": "کے کسی",
                               "کےکنارے": "کے کنارے",
                               "کےکو": "کے کو",
                               "کےکہ": "کے کہ",
                               "کےکہنے": "کے کہنے",
                               "کےکینسر": "کے کینسر",
                               "کےکے": "کے کے",
                               "کےگھر": "کے گھر",
                               "کےگھروں": "کے گھروں",
                               "کےہاتھ": "کے ہاتھ",
                               "کےہاتھوں": "کے ہاتھوں",
                               "کےہم": "کے ہم",
                               "کےہمراہ": "کے ہمراہ",
                               "کےہی": "کے ہی",
                               "کےہیں": "کے ہیں",
                               "گئیاس": "گئی اس",
                               "گئیاور": "گئی اور",
                               "گئیلیکن": "گئی لیکن",
                               "گئیہیں": "گئی ہیں",
                               "گئیںاور": "گئیں اور",
                               "گئےاور": "گئے اور",
                               "گئےجس": "گئے جس",
                               "گئےلیکن": "گئے لیکن",
                               "گئےکہ": "گئے کہ",
                               "گااس": "گا اس",
                               "گاجس": "گا جس",
                               "گالیکن": "گا لیکن",
                               "گامگر": "گا مگر",
                               "گاکہ": "گا کہ",
                               "گاؤںمیں": "گاؤں میں",
                               "گاڑیمیں": "گاڑی میں",
                               "گاڑیکو": "گاڑی کو",
                               "گاڑیکے": "گاڑی کے",
                               "گاڑیوںکی": "گاڑیوں کی",
                               "گذشتہروز": "گذشتہ روز",
                               "گرکر": "گر کر",
                               "گرجچمک": "گرج چمک",
                               "گردوںنے": "گردوں نے",
                               "گردوںکا": "گردوں کا",
                               "گردوںکو": "گردوں کو",
                               "گردیاور": "گردی اور",
                               "گردیکی": "گردی کی",
                               "گرفتارکر": "گرفتار کر",
                               "گرفتاریکے": "گرفتاری کے",
                               "گرمپانی": "گرم پانی",
                               "گرمیکی": "گرمی کی",
                               "گرنےسے": "گرنے سے",
                               "گروپکے": "گروپ کے",
                               "گزرنےکے": "گزرنے کے",
                               "گزشتہبرس": "گزشتہ برس",
                               "گزشتہروز": "گزشتہ روز",
                               "گزشتہماہ": "گزشتہ ماہ",
                               "گزشتہہفتے": "گزشتہ ہفتے",
                               "گفتگومیں": "گفتگو میں",
                               "گفتگوکر": "گفتگو کر",
                               "گلےمیں": "گلے میں",
                               "گنازیادہ": "گنا زیادہ",
                               "گورنرپنجاب": "گورنر پنجاب",
                               "گھرمیں": "گھر میں",
                               "گھروالوں": "گھر والوں",
                               "گھرپر": "گھر پر",
                               "گھرکا": "گھر کا",
                               "گھروںکو": "گھروں کو",
                               "گھنٹوںمیں": "گھنٹوں میں",
                               "گھنٹوںکے": "گھنٹوں کے",
                               "گھنٹےتک": "گھنٹے تک",
                               "گھیرےمیں": "گھیرے میں",
                               "گیاور": "گی اور",
                               "گیلیکن": "گی لیکن",
                               "گیااس": "گیا اس",
                               "گیاتاہم": "گیا تاہم",
                               "گیاتو": "گیا تو",
                               "گیاجس": "گیا جس",
                               "گیاجو": "گیا جو",
                               "گیاجہاں": "گیا جہاں",
                               "گیالیکن": "گیا لیکن",
                               "گیامگر": "گیا مگر",
                               "گیاہو": "گیا ہو",
                               "گیسکی": "گیس کی",
                               "گیسکے": "گیس کے",
                               "گےاور": "گے اور",
                               "گےلیکن": "گے لیکن",
                               "ہاؤسمیں": "ہاؤس میں",
                               "ہائیکورٹ": "ہائی کورٹ",
                               "ہاتھمیں": "ہاتھ میں",
                               "ہاتھوںسے": "ہاتھوں سے",
                               "ہتھیاروںکی": "ہتھیاروں کی",
                               "ہدایتکر": "ہدایت کر",
                               "ہدایتکی": "ہدایت کی",
                               "ہربار": "ہر بار",
                               "ہرجگہ": "ہر جگہ",
                               "ہرروز": "ہر روز",
                               "ہرشخص": "ہر شخص",
                               "ہرطرح": "ہر طرح",
                               "ہرممکن": "ہر ممکن",
                               "ہرچیز": "ہر چیز",
                               "ہرکسی": "ہر کسی",
                               "ہرکو": "ہر کو",
                               "ہرگز": "ہر گز",
                               "ہرگزنہیں": "ہرگز نہیں",
                               "ہزارافراد": "ہزار افراد",
                               "ہزارروپے": "ہزار روپے",
                               "ہزارڈالر": "ہزار ڈالر",
                               "ہزاروںافراد": "ہزاروں افراد",
                               "ہسپتالمنتقل": "ہسپتال منتقل",
                               "ہسپتالوںمیں": "ہسپتالوں میں",
                               "ہفتےکے": "ہفتے کے",
                               "ہلاککر": "ہلاک کر",
                               "ہلاکہو": "ہلاک ہو",
                               "ہلاکہوئے": "ہلاک ہوئے",
                               "ہلیریکلنٹن": "ہلیری کلنٹن",
                               "ہماپنی": "ہم اپنی",
                               "ہمایک": "ہم ایک",
                               "ہمبھی": "ہم بھی",
                               "ہمتو": "ہم تو",
                               "ہمارےحکمران": "ہمارے حکمران",
                               "ہمارےساتھ": "ہمارے ساتھ",
                               "ہمارےلئے": "ہمارے لئے",
                               "ہمارےپاس": "ہمارے پاس",
                               "ہمیشہکے": "ہمیشہ کے",
                               "ہمیںاس": "ہمیں اس",
                               "ہندوستانکی": "ہندوستان کی",
                               "ہواس": "ہو اس",
                               "ہواور": "ہو اور",
                               "ہوتو": "ہو تو",
                               "ہوجا": "ہو جا",
                               "ہوجائیں": "ہو جائیں",
                               "ہوجاتا": "ہو جاتا",
                               "ہوجانے": "ہو جانے",
                               "ہورہا": "ہو رہا",
                               "ہورہی": "ہو رہی",
                               "ہورہے": "ہو رہے",
                               "ہوسکا": "ہو سکا",
                               "ہوسکتا": "ہو سکتا",
                               "ہوسکتی": "ہو سکتی",
                               "ہوسکی": "ہو سکی",
                               "ہوسکیں": "ہو سکیں",
                               "ہوچکا": "ہو چکا",
                               "ہوچکی": "ہو چکی",
                               "ہوچکے": "ہو چکے",
                               "ہوئیتھی": "ہوئی تھی",
                               "ہوئیتھیں": "ہوئی تھیں",
                               "ہوئیجس": "ہوئی جس",
                               "ہوئیکہ": "ہوئی کہ",
                               "ہوئےاسے": "ہوئے اسے",
                               "ہوئےایک": "ہوئے ایک",
                               "ہوئےبتایا": "ہوئے بتایا",
                               "ہوئےبھی": "ہوئے بھی",
                               "ہوئےتو": "ہوئے تو",
                               "ہوئےتھے": "ہوئے تھے",
                               "ہوئےوزیر": "ہوئے وزیر",
                               "ہوئےکیا": "ہوئے کیا",
                               "ہوئےہے": "ہوئے ہے",
                               "ہواتو": "ہوا تو",
                               "ہواتھا": "ہوا تھا",
                               "ہواجب": "ہوا جب",
                               "ہوامیں": "ہوا میں",
                               "ہواکہ": "ہوا کہ",
                               "ہوتاجا": "ہوتا جا",
                               "ہوتیتو": "ہوتی تو",
                               "ہوتیتھی": "ہوتی تھی",
                               "ہوتیہیں": "ہوتی ہیں",
                               "ہوتےتو": "ہوتے تو",
                               "ہوتےتھے": "ہوتے تھے",
                               "ہوتےہوئے": "ہوتے ہوئے",
                               "ہوتےہی": "ہوتے ہی",
                               "ہوناشروع": "ہونا شروع",
                               "ہٹکر": "ہٹ کر",
                               "ہیاس": "ہی اس",
                               "ہیتو": "ہی تو",
                               "ہیسے": "ہی سے",
                               "ہیمیں": "ہی میں",
                               "ہیوہ": "ہی وہ",
                               "ہیکر": "ہی کر",
                               "ہیکو": "ہی کو",
                               "ہیکیا": "ہی کیا",
                               "ہیکے": "ہی کے",
                               "ہیہیں": "ہی ہیں",
                               "ہیںاس": "ہیں اس",
                               "ہیںایک": "ہیں ایک",
                               "ہیںتاہم": "ہیں تاہم",
                               "ہیںجس": "ہیں جس",
                               "ہیںجن": "ہیں جن",
                               "ہیںجو": "ہیں جو",
                               "ہیںمگر": "ہیں مگر",
                               "ہےاب": "ہے اب",
                               "ہےاگر": "ہے اگر",
                               "ہےایک": "ہے ایک",
                               "ہےتاہم": "ہے تاہم",
                               "ہےجس": "ہے جس",
                               "ہےمیں": "ہے میں",
                               "ہےوہ": "ہے وہ",
                               "ہےپاکستان": "ہے پاکستان",
                               "ہےہم": "ہے ہم",
                               "ہےیہ": "ہے یہ",
                               "یاان": "یا ان",
                               "یاتو": "یا تو",
                               "یانہ": "یا نہ",
                               "یاپھر": "یا پھر",
                               "یادرہے": "یاد رہے",

                               }


def fix_join_words(text: str) -> str:
    """
    Replace all join ``urdu`` words with separate words

    Args:
        text (str): raw ``urdu`` text

    Returns:
        str: returns a ``str`` object containing normalized text.
    """
    for key, value in WORDS_SPACE.items():
        text = text.replace(key, value)

    return text
